@@ -30,6 +30,8 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     ,m_check_transpabone( "透明あぼ〜ん" )
     ,m_check_chainabone( "連鎖あぼ〜ん" )
     ,m_check_ageabone( "sage以外をあぼ〜ん" )
+    ,m_check_defnameabone( "デフォルト名無しをあぼ〜ん" )
+    ,m_check_noidabone( "ID無しをあぼ〜ん" )
     ,m_check_boardabone( "板レベルでのあぼ〜んを有効にする" )
     ,m_check_globalabone( "全体レベルでのあぼ〜んを有効にする" )
     ,m_label_since( false, "スレ立て日時 : ", std::string() )
@@ -104,6 +106,12 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     // ageあぼーん
     m_check_ageabone.set_active( DBTREE::get_abone_age( get_url() ) );
 
+    // デフォルト名無しあぼーん
+    m_check_defnameabone.set_active( DBTREE::get_abone_default_name( get_url() ) );
+
+    // ID無しあぼーん
+    m_check_noidabone.set_active( DBTREE::get_abone_noid( get_url() ) );
+
     // 板レベルあぼーん
     m_check_boardabone.set_active( DBTREE::get_abone_board( get_url() ) );
 
@@ -116,6 +124,8 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_vbox_abone.pack_start( m_check_transpabone, Gtk::PACK_SHRINK );
     m_vbox_abone.pack_start( m_check_chainabone, Gtk::PACK_SHRINK );
     m_vbox_abone.pack_start( m_check_ageabone, Gtk::PACK_SHRINK );
+    m_vbox_abone.pack_start( m_check_defnameabone, Gtk::PACK_SHRINK );
+    m_vbox_abone.pack_start( m_check_noidabone, Gtk::PACK_SHRINK );
     m_vbox_abone.pack_start( m_check_boardabone, Gtk::PACK_SHRINK );
     m_vbox_abone.pack_start( m_check_globalabone, Gtk::PACK_SHRINK );
 
@@ -127,13 +137,11 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
 
     if( DBTREE::article_is_cached( get_url() ) ){ 
 
-        std::string str_id, str_res, str_name, str_word, str_regex;
-        std::list< std::string >::iterator it;
+        std::string str_res;
 
         // id
         std::list< std::string > list_id = DBTREE::get_abone_list_id( get_url() );
-        for( it = list_id.begin(); it != list_id.end(); ++it ) if( ! ( *it ).empty() ) str_id += ( *it ) + "\n";
-        m_edit_id.set_text( str_id );
+        m_edit_id.set_text( MISC::concat_with_suffix( list_id, '\n' ) );
         // あぼーんレス番号
         // 連番は 12-34 の様なフォーマットに変換
         const std::unordered_set< int >& set_res = DBTREE::get_abone_reses( get_url() );
@@ -163,18 +171,15 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
 
         // name
         std::list< std::string > list_name = DBTREE::get_abone_list_name( get_url() );
-        for( it = list_name.begin(); it != list_name.end(); ++it ) if( ! ( *it ).empty() ) str_name += ( *it ) + "\n";
-        m_edit_name.set_text( str_name );
+        m_edit_name.set_text( MISC::concat_with_suffix( list_name, '\n' ) );
 
         // word
         std::list< std::string > list_word = DBTREE::get_abone_list_word( get_url() );
-        for( it = list_word.begin(); it != list_word.end(); ++it ) if( ! ( *it ).empty() ) str_word += ( *it ) + "\n";
-        m_edit_word.set_text( str_word );
+        m_edit_word.set_text( MISC::concat_with_suffix( list_word, '\n' ) );
 
         // regex
         std::list< std::string > list_regex = DBTREE::get_abone_list_regex( get_url() );
-        for( it = list_regex.begin(); it != list_regex.end(); ++it ) if( ! ( *it ).empty() ) str_regex += ( *it ) + "\n";
-        m_edit_regex.set_text( str_regex );
+        m_edit_regex.set_text( MISC::concat_with_suffix( list_regex, '\n' ) );
     }
     else{
         m_edit_id.set_editable( false );
@@ -226,10 +231,8 @@ void Preferences::slot_ok_clicked()
     std::vector< char > vec_abone_res;
     vec_abone_res.resize( DBTREE::article_number_load( get_url() ) + 1 );
     std::list< std::string > list_res = MISC::get_lines( m_edit_res.get_text() );
-    std::list< std::string >::iterator it = list_res.begin();
-    for( ; it != list_res.end(); ++it ){
+    for( std::string& num_str : list_res ) {
 
-        std::string num_str = ( *it );
         int number = atoi( num_str.c_str() );
         if( number >= 1 ){
             int number_end = number;
@@ -241,6 +244,7 @@ void Preferences::slot_ok_clicked()
 
     DBTREE::reset_abone( get_url(), list_id, list_name, list_word, list_regex, vec_abone_res
                          , m_check_transpabone.get_active(), m_check_chainabone.get_active(), m_check_ageabone.get_active(),
+                         m_check_defnameabone.get_active(), m_check_noidabone.get_active(),
                          m_check_boardabone.get_active(), m_check_globalabone.get_active() );
 
     // viewの再レイアウト
