@@ -36,6 +36,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
 
     , m_check_live( "実況する" )
 
+    , m_vbox_network{ Gtk::ORIENTATION_VERTICAL, 8 }
+    , m_hbox_agent{ Gtk::ORIENTATION_HORIZONTAL, 2 }
+    , m_label_agent{ "_User-Agent：", true }
     , m_proxy_frame( "読み込み用" )
     , m_proxy_frame_w( "書き込み用" )
 
@@ -53,6 +56,8 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     , m_label_samba( false, "書き込み規制秒数 (Samba24) ：" )
     , m_button_clearsamba( "秒数クリア" )
     , m_check_oldlog( "過去ログを表示する" )
+    , m_hbox_low_number{ Gtk::ORIENTATION_HORIZONTAL, 4 }
+    , m_hbox_high_number{ Gtk::ORIENTATION_HORIZONTAL, 4 }
     , m_button_remove_old_title( "dat落ちしたスレのタイトルを削除する" )
 {
     m_edit_cookies.set_editable( false );
@@ -117,16 +122,17 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     keyword = DBTREE::board_keyword_for_newarticle( get_url() );
     if( ! keyword.empty() ) str_cookies.append( "\nスレ立て用キーワード: " + keyword + "\n" );
 
+    m_edit_cookies.set_hexpand( true );
+    m_edit_cookies.set_propagate_natural_height( true );
     m_edit_cookies.set_text( str_cookies );
 
-    m_hbox_cookie.set_border_width( 8 );
-    m_hbox_cookie.set_spacing( 8 );
-    m_hbox_cookie.pack_start( m_edit_cookies );
-    m_hbox_cookie.pack_start( m_vbox_cookie, Gtk::PACK_SHRINK );
-    m_vbox_cookie.pack_end( m_button_cookie, Gtk::PACK_SHRINK );
+    m_grid_cookie.property_margin() = 8;
+    m_grid_cookie.attach( m_edit_cookies, 0, 0, 1, 1 );
+    m_grid_cookie.attach( m_button_cookie, 1, 0, 1, 1 );
+    m_button_cookie.set_valign( Gtk::ALIGN_END );
     m_button_cookie.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_delete_cookie ) );
 
-    m_frame_cookie.add( m_hbox_cookie );
+    m_frame_cookie.add( m_grid_cookie );
 
     // 実況
     const int live_sec = DBTREE::board_get_live_sec( get_url() );
@@ -207,18 +213,42 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_vbox.pack_start( m_hbox_modified, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_hbox_live, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_check_oldlog, Gtk::PACK_SHRINK );
-    m_vbox.pack_end( m_frame_cookie, Gtk::PACK_SHRINK );
-    m_vbox.pack_end( m_frame_write, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_frame_write, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_frame_cookie, Gtk::PACK_SHRINK );
 
     // ローカルルール
     m_localrule.reset( CORE::ViewFactory( CORE::VIEW_ARTICLEINFO, get_url() ) );
 
+    // ネットワーク設定
+    m_vbox_network.set_border_width( 16 );
+
+    // ユーザーエージェント
+    m_comment_agent.set_text( "通常は about:config で設定したユーザーエージェント(UA)で板にアクセスします\n"
+                              "about:config の設定と異なるUAを使用する場合はここで設定してください (最大200字)\n"
+                              "空欄または不適切な文字が含まれている状態でOKを押すと設定が消去されます" );
+
+    m_label_agent.set_hexpand( false );
+    m_label_agent.set_mnemonic_widget( m_entry_agent );
+
+    m_entry_agent.property_truncate_multiline() = true;
+    m_entry_agent.set_input_purpose( Gtk::INPUT_PURPOSE_ALPHA );
+    m_entry_agent.set_max_length( 200 );
+    m_entry_agent.set_placeholder_text( "空欄のときは about:config の設定が使われます" );
+    const std::string& board_agent = DBTREE::board_get_board_agent( get_url() );
+    if( ! board_agent.empty() ) {
+        m_entry_agent.set_text( board_agent );
+    }
+
+    m_hbox_agent.set_margin_top( 8 );
+    m_hbox_agent.set_margin_bottom( 12 );
+    m_hbox_agent.pack_start( m_label_agent, Gtk::PACK_SHRINK );
+    m_hbox_agent.pack_start( m_entry_agent );
+
     // プロキシ
     std::string host;
-    m_vbox_proxy.set_border_width( 16 );
-    m_vbox_proxy.set_spacing( 8 );
 
-    m_label_proxy.set_text( "通常は全体プロキシ設定でプロキシを設定します\n全体プロキシ設定と異なるプロキシを使用する場合はここで設定して下さい");
+    m_comment_proxy.set_text( "通常は全体プロキシ設定でプロキシを設定します\n"
+                              "全体プロキシ設定と異なるプロキシを使用する場合はここで設定してください" );
 
     switch( DBTREE::board_get_mode_local_proxy( get_url() ) ){
         case DBTREE::PROXY_GLOBAL: m_proxy_frame.rd_global.set_active(); break;
@@ -240,9 +270,11 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_proxy_frame_w.entry_host.set_text( host );
     m_proxy_frame_w.entry_port.set_text( std::to_string( DBTREE::board_get_local_proxy_port_w( get_url() ) ) );
 
-    m_vbox_proxy.pack_start( m_label_proxy, Gtk::PACK_SHRINK );
-    m_vbox_proxy.pack_start( m_proxy_frame, Gtk::PACK_SHRINK );
-    m_vbox_proxy.pack_start( m_proxy_frame_w, Gtk::PACK_SHRINK );
+    m_vbox_network.pack_start( m_comment_agent, Gtk::PACK_SHRINK );
+    m_vbox_network.pack_start( m_hbox_agent, Gtk::PACK_SHRINK );
+    m_vbox_network.pack_start( m_comment_proxy, Gtk::PACK_SHRINK );
+    m_vbox_network.pack_start( m_proxy_frame, Gtk::PACK_SHRINK );
+    m_vbox_network.pack_start( m_proxy_frame_w, Gtk::PACK_SHRINK );
 
     set_activate_entry( m_proxy_frame.entry_host );
     set_activate_entry( m_proxy_frame.entry_port );
@@ -250,29 +282,22 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     set_activate_entry( m_proxy_frame_w.entry_port );
 
     // あぼーん
-    std::string str_id, str_name, str_word, str_regex;
-    std::string str_thread, str_word_thread, str_regex_thread;
-    std::list< std::string >::iterator it;
 
     // ID
     std::list< std::string > list_id = DBTREE::get_abone_list_id_board( get_url() );
-    for( it = list_id.begin(); it != list_id.end(); ++it ) if( ! ( *it ).empty() ) str_id += ( *it ) + "\n";
-    m_edit_id.set_text( str_id );
+    m_edit_id.set_text( MISC::concat_with_suffix( list_id, '\n' ) );
 
     // name
     std::list< std::string > list_name = DBTREE::get_abone_list_name_board( get_url() );
-    for( it = list_name.begin(); it != list_name.end(); ++it ) if( ! ( *it ).empty() ) str_name += ( *it ) + "\n";
-    m_edit_name.set_text( str_name );
+    m_edit_name.set_text( MISC::concat_with_suffix( list_name, '\n' ) );
 
     // word
     std::list< std::string > list_word = DBTREE::get_abone_list_word_board( get_url() );
-    for( it = list_word.begin(); it != list_word.end(); ++it ) if( ! ( *it ).empty() ) str_word += ( *it ) + "\n";
-    m_edit_word.set_text( str_word );
+    m_edit_word.set_text( MISC::concat_with_suffix( list_word, '\n' ) );
 
     // regex
     std::list< std::string > list_regex = DBTREE::get_abone_list_regex_board( get_url() );
-    for( it = list_regex.begin(); it != list_regex.end(); ++it ) if( ! ( *it ).empty() ) str_regex += ( *it ) + "\n";
-    m_edit_regex.set_text( str_regex );
+    m_edit_regex.set_text( MISC::concat_with_suffix( list_regex, '\n' ) );
 
     m_label_warning.set_text(
         "ここでのあぼーん設定は「" +  DBTREE::board_name( get_url() ) + "」板の全スレに適用されます。\n\n"
@@ -290,16 +315,25 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     // スレ数、時間
     m_label_abone_thread.set_text( "以下の数字が0の時は、設定メニューの全体あぼ〜ん設定で指定した数字が用いられます。\nまたキャッシュにログがあるスレはあぼ〜んされません。\n\n" );
 
-    m_label_number.set_text( "レス以上のスレをあぼ〜ん" );
-    m_spin_number.set_range( 0, 9999 );
-    m_spin_number.set_increments( 1, 1 );
-    m_spin_number.set_value( DBTREE::get_abone_number_thread( get_url() ) );
-            
-    m_hbox_number.set_spacing( 4 );
-    m_hbox_number.pack_start( m_spin_number, Gtk::PACK_SHRINK );
-    m_hbox_number.pack_start( m_label_number, Gtk::PACK_SHRINK );
+    m_label_low_number.set_text( "レス以下のスレをあぼ〜ん" );
+    m_spin_low_number.set_range( 0, CONFIG::get_max_resnumber() );
+    m_spin_low_number.set_increments( 1, 1 );
+    m_spin_low_number.set_value( DBTREE::get_abone_low_number_thread( get_url() ) );
 
-    set_activate_entry( m_spin_number );
+    m_hbox_low_number.pack_start( m_spin_low_number, Gtk::PACK_SHRINK );
+    m_hbox_low_number.pack_start( m_label_low_number, Gtk::PACK_SHRINK );
+
+    set_activate_entry( m_spin_low_number );
+
+    m_label_high_number.set_text( "レス以上のスレをあぼ〜ん" );
+    m_spin_high_number.set_range( 0, CONFIG::get_max_resnumber() );
+    m_spin_high_number.set_increments( 1, 1 );
+    m_spin_high_number.set_value( DBTREE::get_abone_high_number_thread( get_url() ) );
+
+    m_hbox_high_number.pack_start( m_spin_high_number, Gtk::PACK_SHRINK );
+    m_hbox_high_number.pack_start( m_label_high_number, Gtk::PACK_SHRINK );
+
+    set_activate_entry( m_spin_high_number );
 
     m_label_hour.set_text( "時間以上スレ立てから経過したスレをあぼ〜ん" );
     m_spin_hour.set_range( 0, 9999 );
@@ -315,13 +349,13 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_vbox_abone_thread.set_border_width( 16 );
     m_vbox_abone_thread.set_spacing( 8 );
     m_vbox_abone_thread.pack_start( m_label_abone_thread, Gtk::PACK_SHRINK );
-    m_vbox_abone_thread.pack_start( m_hbox_number, Gtk::PACK_SHRINK );
+    m_vbox_abone_thread.pack_start( m_hbox_low_number, Gtk::PACK_SHRINK );
+    m_vbox_abone_thread.pack_start( m_hbox_high_number, Gtk::PACK_SHRINK );
     m_vbox_abone_thread.pack_start( m_hbox_hour, Gtk::PACK_SHRINK );
 
     // スレあぼーん
     std::list< std::string > list_thread = DBTREE::get_abone_list_thread( get_url() );
-    for( it = list_thread.begin(); it != list_thread.end(); ++it ) if( ! ( *it ).empty() ) str_thread += ( *it ) + "\n";
-    m_edit_thread.set_text( str_thread );
+    m_edit_thread.set_text( MISC::concat_with_suffix( list_thread, '\n' ) );
 
     m_button_remove_old_title.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_remove_old_title ) );
     m_vbox_abone_title.pack_start( m_edit_thread );
@@ -329,13 +363,11 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
 
     // スレwordあぼーん
     std::list< std::string > list_word_thread = DBTREE::get_abone_list_word_thread( get_url() );
-    for( it = list_word_thread.begin(); it != list_word_thread.end(); ++it ) if( ! ( *it ).empty() ) str_word_thread += ( *it ) + "\n";
-    m_edit_word_thread.set_text( str_word_thread );
+    m_edit_word_thread.set_text( MISC::concat_with_suffix( list_word_thread, '\n' ) );
 
     // スレregexあぼーん
     std::list< std::string > list_regex_thread = DBTREE::get_abone_list_regex_thread( get_url() );
-    for( it = list_regex_thread.begin(); it != list_regex_thread.end(); ++it ) if( ! ( *it ).empty() ) str_regex_thread += ( *it ) + "\n";
-    m_edit_regex_thread.set_text( str_regex_thread );
+    m_edit_regex_thread.set_text( MISC::concat_with_suffix( list_regex_thread, '\n' ) );
 
     m_notebook_abone_thread.append_page( m_vbox_abone_thread, "一般" );
     m_notebook_abone_thread.append_page( m_vbox_abone_title, "NG スレタイトル" );
@@ -349,7 +381,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_notebook.append_page( m_vbox, "一般" );
     const int page_localrule = 1;
     m_notebook.append_page( *m_localrule, "ローカルルール" );
-    m_notebook.append_page( m_vbox_proxy, "プロキシ設定" );
+    m_notebook.append_page( m_vbox_network, "ネットワーク設定" );
     const int page_abone_article = 3;
     m_notebook.append_page( m_notebook_abone, "あぼ〜ん設定(スレビュー)" );
     m_notebook.append_page( m_notebook_abone_thread, "あぼ〜ん設定(スレ一覧)" );
@@ -444,10 +476,7 @@ void Preferences::slot_remove_old_title()
     }
 
     const std::list< std::string > list_thread = DBTREE::get_abone_list_thread_remove( get_url() );
-    std::list< std::string >::const_iterator it = list_thread.begin();
-    std::string str;
-    for( ; it != list_thread.end(); ++it ) if( ! ( *it ).empty() ) str += ( *it ) + "\n";
-    m_edit_thread.set_text( str );
+    m_edit_thread.set_text( MISC::concat_with_suffix( list_thread, '\n' ) );
 }
 
 
@@ -507,6 +536,20 @@ void Preferences::slot_ok_clicked()
     // 過去ログ表示
     if( ! CONFIG::get_show_oldarticle() ) DBTREE::board_set_show_oldlog( get_url(), m_check_oldlog.get_active() );
 
+    // ユーザーエージェント
+    std::string board_agent;
+    const Glib::ustring agent_text = m_entry_agent.get_text();
+    if( ! agent_text.empty() ) {
+        // 不適切な文字が含まれてないかチェックと先頭末尾の空白文字を削除する
+        const std::string& raw = agent_text.raw();
+        if( std::all_of( raw.begin(), raw.end(), []( char c ) { return g_ascii_isprint( c ); } ) ) {
+            board_agent = MISC::remove_spaces( raw );
+        }
+    }
+    if( board_agent != DBTREE::board_get_board_agent( get_url() ) ) {
+        DBTREE::board_set_board_agent( get_url(), board_agent );
+    }
+
     // あぼーん再設定
     std::list< std::string > list_id = MISC::get_lines( m_edit_id.get_text() );
     std::list< std::string > list_name = MISC::get_lines( m_edit_name.get_text() );
@@ -518,11 +561,13 @@ void Preferences::slot_ok_clicked()
     std::list< std::string > list_thread = MISC::get_lines( m_edit_thread.get_text() );
     std::list< std::string > list_word_thread = MISC::get_lines( m_edit_word_thread.get_text() );
     std::list< std::string > list_regex_thread = MISC::get_lines( m_edit_regex_thread.get_text() );
-    const int number = m_spin_number.get_value_as_int();
+    const int low_number = m_spin_low_number.get_value_as_int();
+    const int high_number = m_spin_high_number.get_value_as_int();
     const int hour = m_spin_hour.get_value_as_int();
 
     const bool redraw = true; // ここでスレ一覧の再描画指定をする
-    DBTREE::reset_abone_thread( get_url(), list_thread, list_word_thread, list_regex_thread, number, hour, redraw );  
+    DBTREE::reset_abone_thread( get_url(), list_thread, list_word_thread, list_regex_thread,
+                                low_number, high_number, hour, redraw );
 
     DBTREE::board_save_info( get_url() );
 }
