@@ -114,11 +114,6 @@ std::string CACHE::path_xml_listmain()
     return CACHE::path_root() +  "boards.xml";
 }
 
-std::string CACHE::path_xml_listmain_bkup()
-{
-    return CACHE::path_xml_listmain() + ".bkup";
-}
-
 
 // お気に入り
 std::string CACHE::path_xml_favorite()
@@ -126,11 +121,6 @@ std::string CACHE::path_xml_favorite()
     return CACHE::path_root() +  "bookmark.xml";
 }
 
-std::string CACHE::path_xml_favorite_bkup()
-{
-    return CACHE::path_xml_favorite() + ".bkup";
-}
-
 
 // 外部板設定ファイル( navi2ch 互換 )
 std::string CACHE::path_etcboard()
