@@ -69,13 +69,14 @@ void AboutConfig::pack_widgets()
 
     m_scrollwin.add( m_treeview );
     m_scrollwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
+    m_scrollwin.set_propagate_natural_height( true );
+    m_scrollwin.set_propagate_natural_width( true );
 
     get_content_area()->set_spacing( 8 );
     get_content_area()->pack_start( m_label, Gtk::PACK_SHRINK );
     get_content_area()->pack_start( m_scrollwin );
 
     set_title( "about:config 高度な設定" );
-    set_default_size_ratio( 0.666 );
     show_all_children();
 
     append_rows();
@@ -262,6 +263,8 @@ void AboutConfig::append_rows()
     append_row( "スレビューのスクロールバーを左に配置する", get_confitem()->left_scrbar, CONF_LEFT_SCRBAR );
     append_row( "メニューバーを非表示にした時にダイアログを表示", get_confitem()->show_hide_menubar_diag, CONF_SHOW_HIDE_MENUBAR_DIAG );
     append_row( "状態変更時にメインステータスバーの色を変える", get_confitem()->change_stastatus_color, CONF_CHANGE_STASTATUS_COLOR );
+    append_row( "Client-Side Decorationを使うか( 0: 使わない 1: 使う 2: デスクトップに合わせる )",
+                get_confitem()->use_header_bar, CONF_USE_HEADER_BAR );
 
     // 次スレ検索
     append_row( "" );
@@ -395,28 +398,22 @@ void AboutConfig::slot_row_activated( const Gtk::TreeModel::Path& path, Gtk::Tre
     const int type = row[ m_columns.m_col_type ];
     if( type == CONFTYPE_COMMENT ) return;
 
-    SKELETON::PrefDiag* pref = nullptr;
+    else if( type == CONFTYPE_STR ) {
 
-    switch( type ){
-
-        case CONFTYPE_STR:
-            pref = new AboutConfigDiagStr( this, row[ m_columns.m_col_value_str ], row[ m_columns.m_col_default_str ] );
-            pref->run();
-            set_value( row, *row[ m_columns.m_col_value_str ] );
-            break;
-
-        case CONFTYPE_INT:
-            pref = new AboutConfigDiagInt( this, row[ m_columns.m_col_value_int ], row[ m_columns.m_col_default_int ] );
-            pref->run();
-            set_value( row, *row[ m_columns.m_col_value_int ] );
-            break;
-
-        case CONFTYPE_BOOL:
-            pref = new AboutConfigDiagBool( this, row[ m_columns.m_col_value_bool ], row[ m_columns.m_col_default_bool ] );
-            pref->run();
-            set_value( row, *row[ m_columns.m_col_value_bool ] );
-            break;
+        AboutConfigDiagStr pref( this, row[ m_columns.m_col_value_str ], row[ m_columns.m_col_default_str ] );
+        pref.run();
+        set_value( row, *row[ m_columns.m_col_value_str ] );
     }
+    else if( type == CONFTYPE_INT ) {
 
-    if( pref ) delete pref;
+        AboutConfigDiagInt pref( this, row[ m_columns.m_col_value_int ], row[ m_columns.m_col_default_int ] );
+        pref.run();
+        set_value( row, *row[ m_columns.m_col_value_int ] );
+    }
+    else if( type == CONFTYPE_BOOL ) {
+
+        AboutConfigDiagBool pref( this, row[ m_columns.m_col_value_bool ], row[ m_columns.m_col_default_bool ] );
+        pref.run();
+        set_value( row, *row[ m_columns.m_col_value_bool ] );
+    }
 }
