@@ -9,11 +9,6 @@
 
 #include "gtkmmversion.h"
 
-#include <gtkmm.h>
-#include <list>
-#include <memory>
-#include <string>
-
 #include "skeleton/dispatchable.h"
 #include "skeleton/hpaned.h"
 #include "skeleton/vpaned.h"
@@ -22,6 +17,13 @@
 
 #include "command_args.h"
 
+#include <gtkmm.h>
+
+#include <list>
+#include <memory>
+#include <string>
+
+
 class JDWinMain;
 
 
@@ -96,7 +98,7 @@ namespace CORE
         SKELETON::JDVPaned m_vpaned_message; // 埋め込み書き込みビュー用
 
         // ツールバー
-        MainToolBar* m_toolbar{};
+        std::unique_ptr<MainToolBar> m_toolbar;
 
         // タイトルに表示する文字列
         // set_maintitle() 参照
@@ -136,8 +138,8 @@ namespace CORE
 
     private:
 
-        bool is_3pane();
-        bool is_all_admin_empty();
+        bool is_3pane() const;
+        bool is_all_admin_empty() const;
 
         Gtk::Paned* get_rpane();
         SKELETON::PaneControl* get_rpctrl();
@@ -193,7 +195,7 @@ namespace CORE
         void slot_switch_page( Gtk::Widget*, guint page );
 
         // 右ペーンのnotebookのページ番号
-        int get_right_current_page();
+        int get_right_current_page() const;
 
         // 右ペーンのnotebookのページをセット
         void set_right_current_page( int page );
