@@ -19,7 +19,7 @@ namespace DBIMG
     class DelImgCacheDiag : public Gtk::Dialog, SKELETON::Dispatchable
     {
         Gtk::Label m_label;
-       
+
         bool m_stop; // = true にするとスレッド停止
         JDLIB::Thread m_thread;
 
@@ -42,7 +42,7 @@ namespace DBIMG
         void callback_dispatch() override;
         void wait();
         void slot_cancel_clicked();
-        time_t get_days( const std::string& path );
+        static int get_days( const std::string& path );
         void launch_thread();
     };
 }
