@@ -5,9 +5,11 @@
 #ifndef _IMGROOT_H
 #define _IMGROOT_H
 
-#include <string>
-#include <map>
 #include <list>
+#include <map>
+#include <memory>
+#include <string>
+
 
 namespace DBIMG
 {
@@ -15,36 +17,42 @@ namespace DBIMG
 
     class ImgRoot
     {
-        std::map< std::string, Img* > m_map_img;
+        std::map<std::string, std::unique_ptr<Img>> m_map_img;
         std::list< Img* > m_list_wait; // ロード待ち状態のImgクラス
         std::list< Img* > m_list_delwait; // ロード待ち状態のImgクラスを削除する時の一時変数
-        
+        bool m_webp_support{}; // WebP の読み込みに対応しているか
+        bool m_avif_support{}; // AVIF の読み込みに対応しているか
+
       public:
         ImgRoot();
         ~ImgRoot();
 
+        bool is_webp_support() const noexcept { return m_webp_support; }
+        bool is_avif_support() const noexcept { return m_avif_support; }
+
         void clock_in();
 
         // ロード待ちのためクロックを回すImgクラスをセット/リセット
         void set_clock_in( Img* img );
         void reset_clock_in( Img* img );
         void remove_clock_in();
-        int get_wait_size(){ return m_list_wait.size(); }
+        int get_wait_size() const noexcept { return m_list_wait.size(); }
 
         // Imgクラス取得(無ければ作成)
         Img* get_img( const std::string& url );
 
         // 検索(無ければnullptr)
-        Img* search_img( const std::string& url );
+        Img* search_img( const std::string& url ) = delete;
 
         // 画像データの先頭のシグネチャを見て画像のタイプを取得
         // 画像ではない場合は T_NOIMG を返す
-        int get_image_type( const unsigned char *sign );
+        // 読み込みが未対応の場合は T_NOT_SUPPORT を返す
+        int get_image_type( const unsigned char *sign ) const;
 
         // 拡張子から画像タイプを取得
         // 画像ではない場合は T_UNKNOWN を返す
-        int get_type_ext( const std::string& url );
-        int get_type_ext( const char* url, int n );
+        int get_type_ext( const std::string& url ) const;
+        int get_type_ext( const char* url, int n ) const;
 
         // キャッシュ削除
         void delete_cache( const std::string& url );
@@ -54,10 +62,12 @@ namespace DBIMG
 
       private:
 
-        bool is_jpg( const char* url, int n );
-        bool is_png( const char* url, int n );
-        bool is_gif( const char* url, int n );
-        bool is_bmp( const char* url, int n );
+        static bool is_jpg( const char* url, int n );
+        static bool is_png( const char* url, int n );
+        static bool is_gif( const char* url, int n );
+        static bool is_bmp( const char* url, int n );
+        static bool is_webp( const char* url, int n );
+        static bool is_avif( const char* url, int n );
 
         void reset_imgs();
     };
