@@ -78,6 +78,8 @@ namespace DBTREE
         bool m_abone_transparent{}; // 透明あぼーん
         bool m_abone_chain{}; // 連鎖あぼーん
         bool m_abone_age{}; // age ているレスをあぼーん
+        bool m_abone_default_name{}; // デフォルト名無しをあぼーん
+        bool m_abone_noid{}; // ID無しをあぼーん
         bool m_abone_board; // 板レベルでのあぼーんを有効にする
         bool m_abone_global; // 全体レベルでのあぼーんを有効にする
 
@@ -328,8 +330,14 @@ namespace DBTREE
         // ageあぼーん
         bool get_abone_age() const { return m_abone_age; }
 
+        // デフォルト名無しあぼーん
+        bool get_abone_default_name() const { return m_abone_default_name; }
+
+        // ID無しあぼーん
+        bool get_abone_noid() const noexcept { return m_abone_noid; }
+
         // 板レベルでのあぼーん
-        bool get_abone_board() const { return m_abone_board; }
+        bool get_abone_board() const noexcept { return m_abone_board; }
 
         // 全体レベルでのあぼーん
         bool get_abone_global() const { return m_abone_global; }
@@ -347,6 +355,7 @@ namespace DBTREE
                           const std::list< std::string >& regexs,
                           const std::vector< char >& vec_abone_res,
                           const bool transparent, const bool chain, const bool age,
+                          const bool default_name, const bool noid,
                           const bool board, const bool global
             );
 
@@ -358,6 +367,8 @@ namespace DBTREE
         void set_abone_transparent( const bool set ); // 透明
         void set_abone_chain( const bool set ); // 連鎖
         void set_abone_age( const bool set ); // age
+        void set_abone_default_name( const bool set ); // デフォルト名無し
+        void set_abone_noid( const bool set ); // ID無し
         void set_abone_board( const bool set ); // 板レベルでのあぼーん
         void set_abone_global( const bool set ); // 全体レベルでのあぼーん
 
