@@ -38,7 +38,7 @@ std::string ArticleJBBS::create_write_message( const std::string& name, const st
 
     // DIR と BBS を分離する( ID = DIR/BBS )
     std::string boardid = DBTREE::board_id( get_url() );
-    int i = boardid.find( "/" );
+    int i = boardid.find( '/' );
     std::string dir = boardid.substr( 0, i );
     std::string bbs = boardid.substr( i + 1 );
 
@@ -69,7 +69,7 @@ std::string ArticleJBBS::create_write_message( const std::string& name, const st
 // (例) "http://jbbs.shitaraba.net/bbs/write.cgi/computer/123/1234567/"
 //
 //
-std::string ArticleJBBS::url_bbscgi()
+std::string ArticleJBBS::url_bbscgi() const
 {
     return DBTREE::url_bbscgibase( get_url() ) + DBTREE::board_id( get_url() ) + "/" + get_key() + "/";
 }
@@ -80,7 +80,7 @@ std::string ArticleJBBS::url_bbscgi()
 //
 // (例) "http://jbbs.shitaraba.net/bbs/write.cgi/computer/123/1234567/"
 //
-std::string ArticleJBBS::url_subbbscgi()
+std::string ArticleJBBS::url_subbbscgi() const
 {
     return DBTREE::url_subbbscgibase( get_url() ) + DBTREE::board_id( get_url() ) + "/" + get_key() + "/";
 }
