@@ -25,15 +25,15 @@ namespace DBTREE
                                           const std::string& msg ) override;
 
         // bbscgi のURL
-        std::string url_bbscgi() override;
-        
+        std::string url_bbscgi() const override;
+
         // subbbscgi のURL
-        std::string url_subbbscgi() override;
+        std::string url_subbbscgi() const override;
 
       private:
         
         // 更新チェック不可能
-        bool enable_check_update() override { return false; }
+        bool enable_check_update() const override { return false; }
 
         NodeTreeBase* create_nodetree() override;
     };
