@@ -357,10 +357,8 @@ void Board2chCompati::regist_article( const bool is_online )
 
     const std::string datbase = url_datbase();
 
-    for( unsigned int i = 0; i < get_list_artinfo().size(); ++i ){
+    for( const ARTICLE_INFO& artinfo : get_list_artinfo() ) {
 
-        const ARTICLE_INFO& artinfo = get_list_artinfo()[ i ];
-        
         // DBに登録されてるならarticle クラスの情報更新
         ArticleBase* article = get_article( datbase, artinfo.id );
 
@@ -518,9 +516,17 @@ void Board2chCompati::download_rule_setting()
 
 
 //
-// レス数であぼーん(グローバル)
+// レス数以下であぼーん(グローバル)
 //
-int Board2chCompati::get_abone_number_global() const
+int Board2chCompati::get_abone_low_number_global() const
 {
-    return CONFIG::get_abone_number_thread();
+    return CONFIG::get_abone_low_number_thread();
+}
+
+//
+// レス数以上であぼーん(グローバル)
+//
+int Board2chCompati::get_abone_high_number_global() const
+{
+    return CONFIG::get_abone_high_number_thread();
 }
