@@ -108,7 +108,7 @@ bool BoardBase::empty() const
 bool BoardBase::equal( const std::string& url ) const
 {
     if( url.rfind( get_root(), 0 ) == 0
-        && url.find( get_path_board() + "/" ) != std::string::npos ) return true;
+        && url.find( get_path_board() + "/", get_root().size() ) != std::string::npos ) return true;
 
     return false;
 }
@@ -133,7 +133,12 @@ void BoardBase::update_name( const std::string& name )
 // ダウンロード用
 const std::string& BoardBase::get_agent() const
 {
-    return CONFIG::get_agent_for_data();
+    if( get_board_agent().empty() ) {
+        return CONFIG::get_agent_for_data();
+    }
+    else {
+        return get_board_agent();
+    }
 }
 
 // 書き込み用
@@ -358,12 +363,11 @@ void BoardBase::send_update_board()
 
 
     // ダウンロードを開始したビューの内容を更新する
-    std::list< std::string >::iterator it = m_url_update_views.begin();
-    for( ; it != m_url_update_views.end(); ++it ){
+    for( const std::string& url : m_url_update_views ) {
 #ifdef _DEBUG
-        std::cout << "update : " << *it << std::endl;
+        std::cout << "update : " << url << std::endl;
 #endif 
-        CORE::core_set_command( "update_board", *it );
+        CORE::core_set_command( "update_board", url );
     }
     m_url_update_views.clear();
 }
@@ -1127,7 +1131,7 @@ void BoardBase::receive_finish()
         send_update_board();
 
         // Locationヘッダーで移転先を指定された場合
-        if( get_code() == HTTP_MOVED_PERM && ! location().empty() ) {
+        if( ( get_code() == HTTP_MOVED_PERM || get_code() == HTTP_REDIRECT ) && ! location().empty() ) {
 
             // location() は url_boardbase() の移転先 (start_checkking_if_board_moved() を参照)
             if( DBTREE::move_board( url_boardbase(), location() ) ) {
@@ -1305,14 +1309,11 @@ void BoardBase::receive_finish()
         if( m_is_online ){
 
             // 既読スレに更新があったかチェック
-            std::vector< ArticleBase* >::iterator it_art;
-            for( it_art = m_list_subject.begin(); it_art != m_list_subject.end(); ++it_art ){
-
-                if( ( *it_art )->is_cached() && ( *it_art )->get_number() > ( *it_art )->get_number_load() ){
-
-                    m_status |= STATUS_UPDATED;
-                    break;
-                }
+            const auto is_updated = []( const ArticleBase* a ) {
+                return a->is_cached() && a->get_number() > a->get_number_load();
+            };
+            if( std::any_of( m_list_subject.cbegin(), m_list_subject.cend(), is_updated ) ) {
+                m_status |= STATUS_UPDATED;
             }
 
             show_updateicon( false );
@@ -1470,20 +1471,18 @@ void BoardBase::append_all_article_in_cache()
 #ifdef _DEBUG
     std::cout << "BoardBase::append_all_article_in_cache url = " << datbase << std::endl;
 #endif
-    
-    std::list< std::string >list_file = get_filelist_in_cache();
 
-    std::list< std::string >::iterator it = list_file.begin();
-    for(; it != list_file.end(); ++it ){
+    std::list<std::string> list_file = get_filelist_in_cache();
+    for( const std::string& id : list_file ) {
 
 #ifdef _DEBUG
-        std::cout << "append id = " << ( *it ) << std::endl;
+        std::cout << "append id = " << id << std::endl;
 #endif
 
         // キャッシュあり( cached = true ) 指定でDBに登録
         // キャッシュに無いスレはsubject.txtを読み込んだ時に
         // 派生クラスのparse_subject()で登録する。
-        append_article( datbase, ( *it ),
+        append_article( datbase, id,
                         true  // キャッシュあり
             );
     }
@@ -1510,15 +1509,20 @@ bool BoardBase::is_abone_thread( ArticleBase* article )
     if( ! article ) return false;
     if( article->empty() ) return false;
 
-    const int check_number = article->get_number_load() ? 0: ( m_abone_number_thread ? m_abone_number_thread : get_abone_number_global() );
-    const int check_hour = article->get_number_load() ? 0: ( m_abone_hour_thread ? m_abone_hour_thread : CONFIG::get_abone_hour_thread() );
+    const int load = article->get_number_load();
+    const auto get_check_number = [load]( int board, int global ) { return load ? 0 : ( board ? board : global ); };
+
+    const int check_low_number = get_check_number( m_abone_low_number_thread, get_abone_low_number_global() );
+    const int check_high_number = get_check_number( m_abone_high_number_thread, get_abone_high_number_global() );
+    const int check_hour = get_check_number( m_abone_hour_thread, CONFIG::get_abone_hour_thread() );
     const bool check_thread = ! m_list_abone_thread.empty();
     const bool check_word = ! m_list_abone_word_thread.empty();
     const bool check_regex = ! m_list_abone_regex_thread.empty();
     const bool check_word_global = ! CONFIG::get_list_abone_word_thread().empty();
     const bool check_regex_global = ! CONFIG::get_list_abone_regex_thread().empty();
 
-    if( !check_number && !check_hour && !check_thread && !check_word && !check_regex && !check_word_global && !check_regex_global ) return false;
+    if( !check_low_number && !check_high_number && !check_hour && !check_thread && !check_word && !check_regex
+        && !check_word_global && !check_regex_global ) return false;
 
     JDLIB::Regex regex;
     const size_t offset = 0;
@@ -1528,20 +1532,20 @@ bool BoardBase::is_abone_thread( ArticleBase* article )
     const bool wchar = CONFIG::get_abone_wchar();
 
     // レスの数であぼーん
-    if( check_number ) if( article->get_number() >= check_number ) return true;
+    if( check_low_number && article->get_number() <= check_low_number ) return true;
+    if( check_high_number && article->get_number() >= check_high_number ) return true;
 
     // スレ立てからの時間であぼーん
     if( check_hour ) if( article->get_hour() >= check_hour ) return true;
     
     // スレあぼーん
     if( check_thread ){
-        std::list< std::string >::iterator it = m_list_abone_thread.begin();
-        for( ; it != m_list_abone_thread.end(); ++it ){
-            if( MISC::remove_space( article->get_subject() ) == MISC::remove_space(*it) ){
+        for( const std::string& subject : m_list_abone_thread ) {
+            if( MISC::remove_space( article->get_subject() ) == MISC::remove_space( subject ) ){
 
                 // 対象スレがDat落ちした場合はあぼーんしなかったスレ名をリストから消去する
                 // remove_old_abone_thread() も参照
-                m_list_abone_thread_remove.push_back( *it );
+                m_list_abone_thread_remove.push_back( subject );
                 return true;
             }
         }
@@ -1549,33 +1553,29 @@ bool BoardBase::is_abone_thread( ArticleBase* article )
 
     // ローカル NG word
     if( check_word ){
-        std::list< std::string >::iterator it = m_list_abone_word_thread.begin();
-        for( ; it != m_list_abone_word_thread.end(); ++it ){
-            if( article->get_subject().find( *it ) != std::string::npos ) return true;
+        for( const std::string& word : m_list_abone_word_thread ) {
+            if( article->get_subject().find( word ) != std::string::npos ) return true;
         }
     }
 
     // ローカル NG regex
     if( check_regex ){
-        std::list< std::string >::iterator it = m_list_abone_regex_thread.begin();
-        for( ; it != m_list_abone_regex_thread.end(); ++it ){
-            if( regex.exec( *it, article->get_subject(), offset, icase, newline, usemigemo, wchar ) ) return true;
+        for( const std::string& pat : m_list_abone_regex_thread ) {
+            if( regex.exec( pat, article->get_subject(), offset, icase, newline, usemigemo, wchar ) ) return true;
         }
     }
 
     // 全体 NG word
     if( check_word_global ){
-        std::list< std::string >::iterator it = CONFIG::get_list_abone_word_thread().begin();
-        for( ; it != CONFIG::get_list_abone_word_thread().end(); ++it ){
-            if( article->get_subject().find( *it ) != std::string::npos ) return true;
+        for( const std::string& word : CONFIG::get_list_abone_word_thread() ) {
+            if( article->get_subject().find( word ) != std::string::npos ) return true;
         }
     }
 
     // 全体 NG regex
     if( check_regex_global ){
-        std::list< std::string >::iterator it = CONFIG::get_list_abone_regex_thread().begin();
-        for( ; it != CONFIG::get_list_abone_regex_thread().end(); ++it ){
-            if( regex.exec( *it, article->get_subject(), offset, icase, newline, usemigemo, wchar ) ) return true;
+        for( const std::string& pat : CONFIG::get_list_abone_regex_thread() ) {
+            if( regex.exec( pat, article->get_subject(), offset, icase, newline, usemigemo, wchar ) ) return true;
         }
     }
 
@@ -1597,11 +1597,9 @@ void BoardBase::remove_old_abone_thread()
 
 #ifdef _DEBUG
     std::cout << "BoardBase::remove_old_abone_thread\n";
-    std::list< std::string >::const_iterator it1 = m_list_abone_thread.begin();
-    for( ; it1 != m_list_abone_thread.end(); ++it1 ) std::cout << ( *it1 ) << std::endl;
+    for( const std::string& s : m_list_abone_thread ) std::cout << s << std::endl;
     std::cout << "->\n";
-    std::list< std::string >::const_iterator it2 = m_list_abone_thread_remove.begin();
-    for( ; it2 != m_list_abone_thread_remove.end(); ++it2 ) std::cout << ( *it2 ) << std::endl;
+    for( const std::string& s : m_list_abone_thread_remove ) std::cout << s << std::endl;
 #endif
 
     if( CONFIG::get_remove_old_abone_thread() == 0 ){
@@ -1628,15 +1626,15 @@ void BoardBase::remove_old_abone_thread()
         if( ret != Gtk::RESPONSE_YES ) return;
     }
 
-    std::list< std::string >::iterator it = m_list_abone_thread.begin();
-    for( ; it != m_list_abone_thread.end(); ++it ){
+    // dat落ちしたスレタイトルをNGリストから取り除く
+    for( auto it = m_list_abone_thread.cbegin(); it != m_list_abone_thread.cend(); ) {
 
-        if( std::find( m_list_abone_thread_remove.begin(), m_list_abone_thread_remove.end(), *it )
-            == m_list_abone_thread_remove.end() ){
-
-            m_list_abone_thread.erase( it );
-            it = m_list_abone_thread.begin();
-            continue;
+        const auto cend = m_list_abone_thread_remove.cend();
+        if( std::find( m_list_abone_thread_remove.cbegin(), cend, *it ) == cend ) {
+            it = m_list_abone_thread.erase( it );
+        }
+        else {
+            ++it;
         }
     }
 }
@@ -1743,7 +1741,8 @@ void BoardBase::add_abone_word_board( const std::string& word )
 void BoardBase::reset_abone_thread( const std::list< std::string >& threads,
                                     const std::list< std::string >& words,
                                     const std::list< std::string >& regexs,
-                                    const int number,
+                                    const int low_number,
+                                    const int high_number,
                                     const int hour,
                                     const bool redraw
     )
@@ -1765,7 +1764,8 @@ void BoardBase::reset_abone_thread( const std::list< std::string >& threads,
     m_list_abone_regex_thread = MISC::remove_space_from_list( regexs );
     m_list_abone_regex_thread = MISC::remove_nullline_from_list( m_list_abone_regex_thread );
 
-    m_abone_number_thread = number;
+    m_abone_low_number_thread = low_number;
+    m_abone_high_number_thread = high_number;
     m_abone_hour_thread = hour;
 
     update_abone_thread( redraw );
@@ -1881,21 +1881,13 @@ void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
 
         if( CACHE::load_rawdata( path, rawdata ) > 0 ){
 
-            bool apnd = true;
-
 #ifdef _DEBUG
             std::cout << "load " << path << " size = " << rawdata.size() << " byte" << std::endl;
 #endif
+            // 今の所 AND だけ対応
+            const auto search = [&rawdata]( const auto& q ) { return rawdata.find( q ) != std::string::npos; };
+            const bool apnd = std::all_of( list_query.cbegin(), list_query.cend(), search );
 
-            std::list< std::string >::const_iterator it_query = list_query.begin();
-            for( ; it_query != list_query.end(); ++it_query ){
-
-                // 今の所 AND だけ対応
-                if( rawdata.find( *it_query ) == std::string::npos ){
-                    apnd = false;
-                    break;
-                }
-            }
 
             if( apnd ){
 
@@ -2019,7 +2011,9 @@ void BoardBase::read_board_info()
     if( ! str_tmp.empty() ) m_list_abone_regex_thread = MISC::strtolist( str_tmp );
 
     // レス数であぼーん
-    m_abone_number_thread = cf.get_option_int( "abonenumberthread", 0, 0, 9999 );
+    // abonenumberthread は変数や関数と名前が異なるが互換性のため維持する
+    m_abone_low_number_thread = cf.get_option_int( "abonelownumberthread", 0, 0, CONFIG::get_max_resnumber() );
+    m_abone_high_number_thread = cf.get_option_int( "abonenumberthread", 0, 0, CONFIG::get_max_resnumber() );
 
     // スレ立てからの経過時間であぼーん
     m_abone_hour_thread = cf.get_option_int( "abonehourthread", 0, 0, 9999 );
@@ -2073,6 +2067,9 @@ void BoardBase::read_board_info()
     // 最大レス数
     m_number_max_res = cf.get_option_int( "max_res", get_default_number_max_res(), 0, CONFIG::get_max_resnumber() );
 
+    // 板のユーザーエージェント設定
+    m_board_agent = cf.get_option_str( "user_agent", std::string{} );
+
 #ifdef _DEBUG
     std::cout << "modified = " << get_date_modified() << std::endl;
 #endif
@@ -2146,7 +2143,8 @@ void BoardBase::save_jdboard_info()
          << "abonethread = " << str_abone_thread << std::endl
          << "abonewordthread = " << str_abone_word_thread << std::endl
          << "aboneregexthread = " << str_abone_regex_thread << std::endl
-         << "abonenumberthread = " << m_abone_number_thread << std::endl
+         << "abonelownumberthread = " << m_abone_low_number_thread << std::endl
+         << "abonenumberthread = " << m_abone_high_number_thread << std::endl
          << "abonehourthread = " << m_abone_hour_thread << std::endl
          << "mode_local_proxy = " << m_mode_local_proxy << std::endl
 
@@ -2162,6 +2160,7 @@ void BoardBase::save_jdboard_info()
          << "last_access_time = " << m_last_access_time << std::endl
          << "status = " << m_status << std::endl
          << "max_res = " << m_number_max_res << std::endl
+         << "user_agent = " << m_board_agent << std::endl
     ;
 
     CACHE::save_rawdata( path_info, sstr.str() );
@@ -2186,10 +2185,8 @@ void BoardBase::save_summary()
     std::ostringstream sstr_out;
     sstr_out << "(";
 
-    std::vector< ArticleBase* >::iterator it;
-    for( it = m_list_subject.begin(); it != m_list_subject.end(); ++it ){
+    for( ArticleBase* art : m_list_subject ) {
 
-        ArticleBase* art = *( it );
         if( art->is_cached()
             && ( art->get_status() & STATUS_NORMAL ) ){
             if( count ) sstr_out << " ";
@@ -2245,12 +2242,10 @@ void BoardBase::save_board_info()
         std::cout << "str_info " << str_info << std::endl;
 #endif
 
-        std::list< std::string > lists = MISC::get_elisp_lists( str_info );
-        std::list< std::string >::iterator it = lists.begin();
-        for( ; it != lists.end(); ++it ){
-            if( ( *it ).find( "bookmark" ) != std::string::npos ) bookmark = *it;
-            if( ( *it ).find( "hide" ) != std::string::npos ) hide = *it;
-            if( ( *it ).find( "logo" ) != std::string::npos ) logo = *it;
+        for( const std::string& elem : MISC::get_elisp_lists( str_info ) ) {
+            if( elem.find( "bookmark" ) != std::string::npos ) bookmark = elem;
+            if( elem.find( "hide" ) != std::string::npos ) hide = elem;
+            if( elem.find( "logo" ) != std::string::npos ) logo = elem;
         }
     }
 
