@@ -705,6 +705,16 @@ time_t DBTREE::board_last_access_time( const std::string& url )
     return DBTREE::get_board( url )->get_last_access_time();
 }
 
+const std::string& DBTREE::board_get_board_agent( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_board_agent();
+}
+
+void DBTREE::board_set_board_agent( const std::string& url, const std::string& user_agent )
+{
+    DBTREE::get_board( url )->set_board_agent( user_agent );
+}
+
 
 /////////////////////////////////////////////////
 
@@ -778,9 +788,14 @@ const std::list< std::string >& DBTREE::get_abone_list_regex_thread( const std::
     return DBTREE::get_board( url )->get_abone_list_regex_thread();
 }
 
-int DBTREE::get_abone_number_thread( const std::string& url )
+int DBTREE::get_abone_low_number_thread( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_abone_number_thread();
+    return DBTREE::get_board( url )->get_abone_low_number_thread();
+}
+
+int DBTREE::get_abone_high_number_thread( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_abone_high_number_thread();
 }
 
 int DBTREE::get_abone_hour_thread( const std::string& url )
@@ -803,12 +818,13 @@ void DBTREE::reset_abone_thread( const std::string& url,
                                  const std::list< std::string >& threads,
                                  const std::list< std::string >& words,
                                  const std::list< std::string >& regexs,
-                                 const int number,
+                                 const int low_number,
+                                 const int high_number,
                                  const int hour,
                                  const bool redraw
     )
 {
-    DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs, number, hour, redraw );
+    DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs, low_number, high_number, hour, redraw );
 }
 
 /////////////////////////////////////////////////
@@ -1225,10 +1241,12 @@ void DBTREE::reset_abone( const std::string& url,
                           const std::list< std::string >& regexs,
                           const std::vector< char >& vec_abone_res,
                           const bool transparent, const bool chain, const bool age,
+                          const bool default_name, const bool noid,
                           const bool board, const bool global
     )
 {
-    DBTREE::get_article( url )->reset_abone( ids, names, words, regexs, vec_abone_res, transparent, chain, age, board, global );
+    DBTREE::get_article( url )->reset_abone( ids, names, words, regexs, vec_abone_res, transparent, chain, age,
+                                             default_name, noid, board, global );
 }
 
 
@@ -1294,6 +1312,32 @@ void DBTREE::set_abone_age( const std::string& url, const bool set )
 }
 
 
+// デフォルト名無しあぼーん
+bool DBTREE::get_abone_default_name( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_abone_default_name();
+}
+
+
+void DBTREE::set_abone_default_name( const std::string& url, const bool set )
+{
+    DBTREE::get_article( url )->set_abone_default_name( set );
+}
+
+
+// ID無しあぼーん
+bool DBTREE::get_abone_noid( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_abone_noid();
+}
+
+
+void DBTREE::set_abone_noid( const std::string& url, const bool set )
+{
+    DBTREE::get_article( url )->set_abone_noid( set );
+}
+
+
 // 板レベルでのあぼーん
 bool DBTREE::get_abone_board( const std::string& url )
 {
