@@ -191,6 +191,10 @@ namespace DBTREE
     void board_set_live_sec( const std::string& url, time_t sec );
     time_t board_last_access_time( const std::string& url );
 
+    // 板のユーザーエージェント設定
+    const std::string& board_get_board_agent( const std::string& url );
+    void board_set_board_agent( const std::string& url, const std::string& user_agent );
+
     // 全スレの書き込み履歴のリセット
     void clear_all_post_history();
 
@@ -338,7 +342,8 @@ namespace DBTREE
     const std::list< std::string >& get_abone_list_word_thread( const std::string& url );
     const std::list< std::string >& get_abone_list_regex_thread( const std::string& url );
     const std::unordered_set< int >& get_abone_reses( const std::string& url );
-    int get_abone_number_thread( const std::string& url );
+    int get_abone_low_number_thread( const std::string& url );
+    int get_abone_high_number_thread( const std::string& url );
     int get_abone_hour_thread( const std::string& url );
 
     // subject.txtのロード後にdat落ちしたスレッドをスレあぼーんのリストから取り除く
@@ -354,7 +359,8 @@ namespace DBTREE
                              const std::list< std::string >& threads,
                              const std::list< std::string >& words,
                              const std::list< std::string >& regexs,
-                             const int number, const int hour, const bool redraw );
+                             const int low_number, const int high_number,
+                             const int hour, const bool redraw );
 
     //
     // 各articlebase別のあぼーん情報
@@ -383,6 +389,7 @@ namespace DBTREE
                       const std::list< std::string >& regexs,
                       const std::vector< char >& vec_abone_res,
                       const bool transparent, const bool chain, const bool age,
+                      const bool default_name, const bool noid,
                       const bool board, const bool global
         );
 
@@ -404,6 +411,14 @@ namespace DBTREE
     bool get_abone_age( const std::string& url );
     void set_abone_age( const std::string& url, const bool set );
 
+    // デフォルト名無しあぼーん
+    bool get_abone_default_name( const std::string& url );
+    void set_abone_default_name( const std::string& url, const bool set );
+
+    // ID無しあぼーん
+    bool get_abone_noid( const std::string& url );
+    void set_abone_noid( const std::string& url, const bool set );
+
     // 板レベルでのあぼーん
     bool get_abone_board( const std::string& url );
     void set_abone_board( const std::string& url, const bool set );
