@@ -29,11 +29,14 @@
 #include "environment.h"
 #include "global.h"
 
-#include <sstream>
-#include <cstring>
 #include <sys/types.h> // chmod
 #include <sys/stat.h>
 
+#include <cstring>
+#include <iterator>
+#include <sstream>
+
+
 #ifdef _TEST_CACHE
 int cache_hit1 = 0;
 int cache_hit2 = 0;
@@ -156,19 +159,19 @@ BoardBase* Root::get_board( const std::string& url, const int count )
 
     if( count == 0 ){
 
-        size_t pos = url.rfind( "http://" );
+        const std::size_t pos = url.rfind( "http://" );
+        const std::size_t pos2 = url.rfind( "https://" );
 
         // ユーザープロフィールアドレス( http://be.2ch.net/test/p.php?u=d:http://〜 )の様に
         // 先頭以外に http:// が入っている場合は失敗
-        if( pos != std::string::npos && pos != 0 ) return m_board_null.get();
+        if( ( pos != std::string::npos && pos != 0 ) || ( pos2 != std::string::npos && pos2 != 0 ) ) {
+            return m_board_null.get();
+        }
 
-        size_t pos2 = url.rfind( "https://" );
-        if ( pos2 != std::string::npos && pos2 != 0 ) return m_board_null.get();
-        if ( pos2 == 0 ) pos = 0;
-
-        // http[s]:// が含まれていなかったら先頭に追加して再帰呼び出し
-        if( pos == std::string::npos && ! is_local( url ) ){
-            BoardBase* board = get_board( "http://" + url , count + 1 );
+        // http:// が含まれていなかったら先頭に追加して再帰呼び出し
+        else if( pos == std::string::npos && pos2 == std::string::npos && ! is_local( url ) ){
+            const char* scheme{ url.rfind( "//", 0 ) == 0 ? "http:" : "http://" };
+            BoardBase* board = get_board( scheme + url, count + 1 );
             m_get_board_url = url;
             return board;
         }
@@ -369,7 +372,7 @@ void Root::receive_finish()
         return;
     }
 
-    if( get_code() == HTTP_MOVED_PERM && ! location().empty() ){
+    if( ( get_code() == HTTP_MOVED_PERM || get_code() == HTTP_REDIRECT ) && ! location().empty() ){
 
         const std::string msg = get_str_code() + "\n\n板一覧が " + location() + " に移転しました。更新しますか？";
         SKELETON::MsgDiag mdiag( nullptr, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
@@ -484,8 +487,8 @@ void Root::bbsmenu2xml( const std::string& menu )
             // 板として扱うURLかどうかで要素名を変える
             std::string element_name;
             if( CONFIG::use_link_as_board() ) element_name = "board";
-            else if( ( regex.exec( "^https?://.*/.*/$", url, offset, icase, newline, usemigemo, wchar )
-			            && ( is_2ch( url ) || is_machi( url ) ) )
+            else if( ( regex.exec( "^(https?:)?//.*/.*/$", url, offset, icase, newline, usemigemo, wchar )
+                       && ( is_2ch( url ) || is_machi( url ) ) )
                      || is_JBBS( url )
                      || is_vip2ch( url )
                 ) element_name = "board";
@@ -572,9 +575,9 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
     // 2ch
     if( ! etc && is_2ch( url ) ){
 
-        if( regex.exec( "(https?://[^/]*)/([^/]*)/$" , url, offset, icase, newline, usemigemo, wchar ) ){
+        if( regex.exec( "(https?://[^/]*)(/[^/]*)/$" , url, offset, icase, newline, usemigemo, wchar ) ){
             root = regex.str( 1 );
-            path_board = "/" + regex.str( 2 );
+            path_board = regex.str( 2 );
 
             type = TYPE_BOARD_2CH;
         }
@@ -583,9 +586,9 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
     // JBBS
     else if( is_JBBS( url ) ){
 
-        if( regex.exec( "(https?://[^/]*)/(.*)/(index2?\\.html?)?$" , url, offset, icase, newline, usemigemo, wchar ) ){
+        if( regex.exec( "(https?://[^/]*)(/.*)/(index2?\\.html?)?$" , url, offset, icase, newline, usemigemo, wchar ) ){
             root = regex.str( 1 );
-            path_board = "/" + regex.str( 2 );
+            path_board = regex.str( 2 );
 
             type = TYPE_BOARD_JBBS;
         }
@@ -594,9 +597,9 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
     // まち
     else if( is_machi( url ) ){
 
-        if( regex.exec( "(https?://[^/]*)/([^/]*)/(index2?\\.html?)?$" , url, offset, icase, newline, usemigemo, wchar ) ){
+        if( regex.exec( "(https?://[^/]*)(/[^/]*)/(index2?\\.html?)?$" , url, offset, icase, newline, usemigemo, wchar ) ){
             root = regex.str( 1 );
-            path_board = "/" + regex.str( 2 );
+            path_board = regex.str( 2 );
 
             type = TYPE_BOARD_MACHI;
         }
@@ -605,9 +608,9 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
     // vipサービス
     else if( is_vip2ch( url ) ){
 
-        if( regex.exec( "(https?://[^/]*)/([^/]*)/$" , url, offset, icase, newline, usemigemo, wchar ) ){
+        if( regex.exec( "(https?://[^/]*)(/[^/]*)/$" , url, offset, icase, newline, usemigemo, wchar ) ){
             root = regex.str( 1 );
-            path_board = "/" + regex.str( 2 );
+            path_board = regex.str( 2 );
 
             type = TYPE_BOARD_2CH_COMPATI;
         }
@@ -625,9 +628,9 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
     // その他は互換型
     else{
 
-        if( regex.exec( "(https?://.*)/([^/]*)/([^\\.]+\\.html?)?$" , url, offset, icase, newline, usemigemo, wchar ) ){
+        if( regex.exec( "(https?://.*)(/[^/]*)/([^\\.]+\\.html?)?$" , url, offset, icase, newline, usemigemo, wchar ) ){
             root = regex.str( 1 );
-            path_board = "/" + regex.str( 2 );
+            path_board = regex.str( 2 );
 
             type = TYPE_BOARD_2CH_COMPATI;
         }
@@ -682,24 +685,33 @@ bool Root::set_board( const std::string& url, const std::string& name, const std
     std::cout << "Root::set_board " << url << " " << name << std::endl;
 #endif
 
+    std::string real_url;
     std::string root;
     std::string path_board;
 
+    // scheme省略の場合はbbsmenuのURLから補う
+    if( url.rfind( "//", 0 ) == 0 ) {
+        const std::string menu_url = CONFIG::get_url_bbsmenu();
+        const std::size_t pos = menu_url.find( "://" );
+        if( pos != std::string::npos ) real_url = menu_url.substr( 0, pos + 1 );
+    }
+    real_url.append( url );
+
     // タイプ判定
-    int type = get_board_type( url, root, path_board, etc );
+    const int type = get_board_type( real_url, root, path_board, etc );
     if( type == TYPE_BOARD_UNKNOWN ) return false;
 
     // 移転チェック
     BoardBase* board = nullptr;
-    const int stat = is_moved( root, path_board, name, &board, etc );
+    const int state = is_moved( root, path_board, name, &board, etc );
 
 #ifdef _SHOW_BOARD
     std::cout << "root = " << root << " path_board = " << path_board
-              << " basicauth = " << basicauth <<" type = " << type << " stat = " << stat << std::endl;
+              << " basicauth = " << basicauth <<" type = " << type << " state = " << state << std::endl;
 #endif
 
     // 新板登録
-    if( stat == BOARD_NEW ){
+    if( state == BOARD_NEW ){
 
         auto uniq = DBTREE::BoardFactory( type, root, path_board, name, basicauth );
         if( uniq ){
@@ -710,7 +722,7 @@ bool Root::set_board( const std::string& url, const std::string& name, const std
     }
 
     // 移転処理
-    else if( stat == BOARD_MOVED ){
+    else if( state == BOARD_MOVED ){
 
         // XML解析中に、
         // <board name="ニュース実況+" url="http://anchorage.2ch.net/liveplus/" />
@@ -723,7 +735,7 @@ bool Root::set_board( const std::string& url, const std::string& name, const std
             MISC::ERRMSG( tmp_msg );
 
             const std::string path1 = CACHE::path_board_root_fast( board->url_boardbase() );
-            const std::string path2 = CACHE::path_board_root_fast( url );
+            const std::string path2 = CACHE::path_board_root_fast( real_url );
 
 #ifdef _DEBUG
             std::cout << "path1 = " << path1 << std::endl
@@ -927,28 +939,28 @@ void Root::push_movetable( std::string old_root,
 
 #ifdef _DEBUG
         std::cout << "size = " << m_movetable.size() << " "
-                  << ( *it_move ).old_root << ( *it_move ).old_path_board << "/ -> " << ( *it_move ).new_root << std::endl;
-#endif            
+                  << it_move->old_root << it_move->old_path_board << "/ -> " << it_move->new_root << std::endl;
+#endif
 
         if(
-            ( ( *it_move ).old_root == new_root
-              && ( *it_move ).old_path_board == new_path_board )
+            ( it_move->old_root == new_root
+              && it_move->old_path_board == new_path_board )
 
             ||
 
-            ( ( *it_move ).old_root == old_root
-              && ( *it_move ).old_path_board == old_path_board )
+            ( it_move->old_root == old_root
+              && it_move->old_path_board == old_path_board )
 
             ){
 
-            const std::string str_tmp = "削除: " +( *it_move ).old_root + ( *it_move ).old_path_board + "/ -> " + ( *it_move ).new_root + "\n";
+            const std::string str_tmp = "削除: " + it_move->old_root + it_move->old_path_board + "/ -> "
+                                        + it_move->new_root + "\n";
 #ifdef _DEBUG
             std::cout << str_tmp << std::endl;
 #endif
             str += str_tmp;
 
-            m_movetable.erase( it_move );
-            it_move = m_movetable.begin();
+            it_move = m_movetable.erase( it_move );
             continue;
         }
 
@@ -958,23 +970,23 @@ void Root::push_movetable( std::string old_root,
         // erase した内容と push_back した内容が同じになるので無限ループに落ちる
         else if(
 
-            ( *it_move ).new_root == old_root
-            && ( *it_move ).new_path_board == old_path_board ){
+            it_move->new_root == old_root
+            && it_move->new_path_board == old_path_board ){
 
             MOVETABLE movetable = *it_move;
             movetable.new_root = new_root;
             movetable.new_path_board = new_path_board;
 
-            const std::string str_tmp = "更新: " +( *it_move ).old_root + ( *it_move ).old_path_board + "/ -> " + ( *it_move ).new_root
-            + " => " + movetable.old_root + movetable.old_path_board + "/ -> " + movetable.new_root + "\n";
+            const std::string str_tmp = "更新: " + it_move->old_root + it_move->old_path_board + "/ -> "
+                                        + it_move->new_root + " => " + movetable.old_root + movetable.old_path_board
+                                        + "/ -> " + movetable.new_root + "\n";
 #ifdef _DEBUG
             std::cout << str_tmp << std::endl;
 #endif
             str += str_tmp;
 
-            m_movetable.erase( it_move );
+            it_move = m_movetable.erase( it_move );
             m_movetable.push_back( std::move( movetable ) );
-            it_move = m_movetable.begin();
             continue;
         }
 
@@ -1102,15 +1114,15 @@ void Root::load_etc()
             if( it == list_etc.end() ) break;
 
             // basic認証
-            if( regex.exec( "https?://([^/]+:[^/]+@)(.+)$" , info.url, offset, icase, newline, usemigemo, wchar ) )
+            if( regex.exec( "(https?://)([^/]+:[^/]+@)(.+)$" , info.url, offset, icase, newline, usemigemo, wchar ) )
             {
-                info.basicauth = regex.str( 1 ).substr( 0, regex.length( 1 ) - 1 );
-                info.url = ( info.url[4] == 's' ? "https://" : "http://" ) + regex.str( 2 );
+                info.basicauth = regex.str( 2 );
+                info.basicauth.pop_back();
+                info.url = regex.str( 1 ) + regex.str( 3 );
             }
 
             // board id
             info.boardid = *( it );
-            if( it == list_etc.end() ) break;
 
 #ifdef _DEBUG
             std::cout << "etc board : name = " << info.name << std::endl
@@ -1176,10 +1188,9 @@ bool Root::move_etc( const std::string& url_old, const std::string& url_new,
     BoardBase * board = get_board( url_old );
     if( ! board ) return false;
 
-    std::list< DBTREE::ETCBOARDINFO >::iterator it = m_etcboards.begin();
-    for( ; it != m_etcboards.end(); ++it ){
-        if( (*it).url == url_old && (*it).name == name_old ) break;
-    }
+    using Info = DBTREE::ETCBOARDINFO;
+    const auto find_info = [&url_old, &name_old]( const Info& i ) { return i.url == url_old && i.name == name_old; };
+    auto it = std::find_if( m_etcboards.begin(), m_etcboards.end(), find_info );
     if( it == m_etcboards.end() ) return false;
 
 #ifdef _DEBUG
@@ -1222,18 +1233,15 @@ bool Root::remove_etc( const std::string& url, const std::string& name )
 
     if( m_etcboards.empty() ) return false;
 
-    std::list< DBTREE::ETCBOARDINFO >::iterator it = m_etcboards.begin();
-    for( ; it != m_etcboards.end(); ++it ){
-
-        if( (*it).url == url && (*it).name == name ){
+    const auto find_info = [&]( const DBTREE::ETCBOARDINFO& i ) { return i.url == url && i.name == name; };
+    const auto it = std::find_if( m_etcboards.cbegin(), m_etcboards.cend(), find_info );
+    if( it != m_etcboards.cend() ) {
 #ifdef _DEBUG
-            std::cout << "found\n";
+        std::cout << "found\n";
 #endif 
-
-            remove_board( url );
-            m_etcboards.erase( it );
-            return true;
-        }
+        remove_board( url );
+        m_etcboards.erase( it );
+        return true;
     }
 
     return false;
@@ -1255,21 +1263,20 @@ void Root::save_etc()
 
     std::string etcboard;
 
-    std::list< DBTREE::ETCBOARDINFO >::iterator it = m_etcboards.begin();
-    for( ; it != m_etcboards.end(); ++it ){
+    for( const DBTREE::ETCBOARDINFO& info : m_etcboards ) {
 
-        etcboard += (*it).name + "\n";
-        if( (*it).basicauth.empty() ) etcboard += (*it).url + "\n";
+        etcboard += info.name + "\n";
+        if( info.basicauth.empty() ) etcboard += info.url + "\n";
         else{
 
-            size_t i = (*it).url.find( "://" );
+            const std::size_t i = info.url.find( "://" );
             if( i != std::string::npos ){
-                etcboard += (*it).url.substr( 0, i+3 ) + (*it).basicauth + "@" + (*it).url.substr( i+3 ) + "\n";
+                etcboard += info.url.substr( 0, i+3 ) + info.basicauth + "@" + info.url.substr( i+3 ) + "\n";
             }
-            else etcboard += (*it).url + "\n";
+            else etcboard += info.url + "\n";
 
         }
-        etcboard += (*it).boardid + "\n"; 
+        etcboard += info.boardid + "\n";
     }
 
     std::string file_etctxt = CACHE::path_etcboard();
@@ -1300,21 +1307,20 @@ void Root::load_movetable()
     if( CACHE::load_rawdata( file_move, movetable_rawdata ) ){
 
         std::list< std::string > list_table = MISC::get_lines( movetable_rawdata );
-        std::list< std::string >::iterator it;
-        for( it = list_table.begin(); it != list_table.end(); ++it ){
+        for( const std::string& line : list_table ) {
 
-            std::list< std::string > lines = MISC::split_line( *it );
+            std::list<std::string> tokens = MISC::split_line( line );
 
-            if( lines.size() == 3 // 旧形式
-                || lines.size() == 4 ){
+            if( tokens.size() == 3 // 旧形式
+                || tokens.size() == 4 ){
 
-                std::list< std::string >::iterator it2 = lines.begin();
+                auto move_it = std::make_move_iterator( tokens.begin() );
 
                 MOVETABLE movetable;
-                movetable.old_root = *(it2++);
-                movetable.new_root = *(it2++);
-                movetable.old_path_board = *(it2++);
-                if( lines.size() == 4 ) movetable.new_path_board = *(it2++);
+                movetable.old_root = *(move_it++);
+                movetable.new_root = *(move_it++);
+                movetable.old_path_board = *(move_it++);
+                if( tokens.size() == 4 ) movetable.new_path_board = *(move_it++);
                 else movetable.new_path_board = movetable.old_path_board;
                 m_movetable.push_back( movetable );
             }
@@ -1323,13 +1329,10 @@ void Root::load_movetable()
 
 #ifdef _DEBUG
     std::cout << "MOVETABLE : \n";
-    std::list< MOVETABLE >::iterator it_move;
-    for( it_move = m_movetable.begin(); it_move != m_movetable.end(); ++it_move )
-        std::cout << ( *it_move ).old_root << ( *it_move ).old_path_board
-                  << " -> " << ( *it_move ).new_root <<  ( *it_move ).new_path_board << std::endl;
+    for( const MOVETABLE& t : m_movetable ) {
+        std::cout << t.old_root << t.old_path_board << " -> " << t.new_root << t.new_path_board << std::endl;
+    }
 #endif
-
-
 }
 
 
@@ -1429,23 +1432,22 @@ std::string Root::is_board_moved( const std::string& url,
     }
 
     // 移転テーブルを検索
-    std::list< MOVETABLE >::iterator it_move = m_movetable.begin();
-    for( ; it_move != m_movetable.end(); ++it_move ){
+    for( const MOVETABLE& table : m_movetable ) {
 
-        if( url.rfind( ( *it_move ).old_root, 0 ) == 0
-            && url.find( ( *it_move ).old_path_board + "/" ) != std::string::npos ){
+        if( url.rfind( table.old_root, 0 ) == 0
+            && url.find( table.old_path_board + "/" ) != std::string::npos ){
 
-            const std::string new_url = ( *it_move ).new_root + ( *it_move ).new_path_board + "/";
+            const std::string new_url = table.new_root + table.new_path_board + "/";
 
-            old_root = ( *it_move ).old_root;
-            old_path_board = ( *it_move ).old_path_board;
-            new_root = ( *it_move ).new_root;
-            new_path_board = ( *it_move ).new_path_board;
+            old_root = table.old_root;
+            old_path_board = table.old_path_board;
+            new_root = table.new_root;
+            new_path_board = table.new_path_board;
 
-            const std::string old_root_bkup = old_root;
-            const std::string old_path_board_bkup = old_path_board;
+            std::string old_root_bkup = old_root;
+            std::string old_path_board_bkup = old_path_board;
 
-#ifdef _DEBUG            
+#ifdef _DEBUG
             std::cout << "count = " << count << " : " << url << " is moved to " << new_url << std::endl;
 #endif
 
@@ -1455,15 +1457,15 @@ std::string Root::is_board_moved( const std::string& url,
             // old_root と old_path_board が書き換わっているので戻しておく
             //
             // (注意) もし再帰呼び出ししたis_board_moved() の中で m_movetable.erase を実行すると
-            // it_move は無効になるので、以前の様に
-            // old_root = ( *it_move ).old_root;
-            // old_path_board = ( *it_move ).old_path_board;
-            // と it_move を使ってold_rootなどに代入するとメモリを破壊してセグフォになる時がある
+            // table は無効になるので、以前の様に
+            // old_root = table.old_root;
+            // old_path_board = table.old_path_board;
+            // と table を使ってold_rootなどに代入するとメモリを破壊してセグフォになる時がある
             // (イテレータのメモリが残っていればセグフォにならないので完全に運まかせ)
             // 次にJDを起動したときは再帰呼び出ししたis_board_moved() の中の save_movetable()で
             // 移転テーブルは更新済みで落ちないのでタチが悪い
-            old_root = old_root_bkup;
-            old_path_board = old_path_board_bkup;
+            old_root = std::move( old_root_bkup );
+            old_path_board = std::move( old_path_board_bkup );
 
             return ret_url;
         }
@@ -1529,16 +1531,15 @@ void Root::save_movetable()
     std::string file_move = CACHE::path_movetable();
     std::ostringstream movetable;
 
-    std::list< MOVETABLE >::iterator it_move;
-    for( it_move = m_movetable.begin(); it_move != m_movetable.end(); ++it_move ){
+    for( const MOVETABLE& t : m_movetable ) {
 
-        movetable <<( *it_move ).old_root << " "
-                  << ( *it_move ).new_root << " "
-                  << ( *it_move ).old_path_board;
+        movetable << t.old_root << " "
+                  << t.new_root << " "
+                  << t.old_path_board;
 
         // 新形式
-        if( ! ( *it_move ).new_path_board.empty()
-            && ( *it_move ).old_path_board != ( *it_move ).new_path_board ) movetable << " " << ( *it_move ).new_path_board;
+        if( ! t.new_path_board.empty()
+            && t.old_path_board != t.new_path_board ) movetable << " " << t.new_path_board;
 
         movetable << std::endl;
     }
