@@ -13,9 +13,11 @@
 #include "skeleton/loadable.h"
 #include "xml/document.h"
 
-#include <string>
 #include <list>
+#include <memory>
 #include <set>
+#include <string>
+
 
 namespace DBTREE
 {
@@ -50,7 +52,7 @@ namespace DBTREE
     {
         // Boardクラス のキャッシュ
         // Boardクラスは一度作ったら~Root()以外ではdeleteしないこと
-        std::list< BoardBase* > m_list_board;
+        std::list<std::unique_ptr<BoardBase>> m_list_board;
 
         // 鯖移転テーブル
         std::list< MOVETABLE > m_movetable;
@@ -60,17 +62,17 @@ namespace DBTREE
         std::list< DBTREE::ETCBOARDINFO > m_etcboards; // 外部板情報
 
         // 移転処理用変数
-        bool m_analyzing_board_xml;  // XML 解析中
+        bool m_analyzing_board_xml{};  // XML 解析中
         std::set< std::string > m_analyzed_path_board; // XML 解析中に処理済みの板のpath
         std::string m_move_info;  // 移転したときにダイアログに表示する移転済み板の一覧
 
         // Null board クラス
-        BoardBase* m_board_null;
+        std::unique_ptr<BoardBase> m_board_null;
 
         // get_board()のキャッシュ
         // get_article_fromURL()のキャッシュ
         std::string m_get_board_url;
-        BoardBase* m_get_board;
+        BoardBase* m_get_board{};
 
         bool m_enable_save_movetable;
 
@@ -161,8 +163,8 @@ namespace DBTREE
         void analyze_board_xml();
 
         // 板のタイプを判定
-        int get_board_type( const std::string& url, std::string& root, std::string& path_board, const bool etc );
-        int get_board_type( const std::string& root, const bool etc = false );
+        int get_board_type( const std::string& url, std::string& root, std::string& path_board, const bool etc ) const;
+        int get_board_type( const std::string& root, const bool etc = false ) const;
 
         // 板のタイプに合わせて板情報をセット
         bool set_board( const std::string& url, const std::string& name, const std::string& basicauth = std::string(), bool etc = false );
@@ -193,11 +195,11 @@ namespace DBTREE
         void load_movetable();
 
         // urlのタイプ判定
-        bool is_2ch( const std::string& url );
-        bool is_JBBS( const std::string& url );
-        bool is_machi( const std::string& url );
-        bool is_vip2ch( const std::string& url );
-        bool is_local( const std::string& url );
+        static bool is_2ch( const std::string& url );
+        static bool is_JBBS( const std::string& url );
+        static bool is_machi( const std::string& url );
+        static bool is_vip2ch( const std::string& url );
+        static bool is_local( const std::string& url );
     };
 }
 
