@@ -28,10 +28,10 @@ namespace DBTREE
         std::string m_default_noname;
 
         // 最大改行数/2
-        int m_line_number;
+        int m_line_number{};
 
         // 最大書き込みバイト数
-        int m_message_count;
+        int m_message_count{};
 
         // 特殊文字書き込み
         std::string m_unicode;
@@ -48,9 +48,9 @@ namespace DBTREE
 
       protected:
 
-        std::string get_url() override;
-        std::string get_path() override;
-        std::string get_charset() override;
+        std::string get_url() const override;
+        std::string get_path() const override;
+        std::string get_charset() const override;
 
         // ロード用データ作成
         void create_loaderdata( JDLIB::LOADERDATA& data ) override;
