@@ -280,20 +280,18 @@ void History_Manager::viewhistory2xml()
     const std::list< std::string >& article_urls = SESSION::get_article_URLs();
     const std::list< std::string >& board_urls = SESSION::get_board_URLs();
 
-    std::list< std::string >::const_iterator it_url = article_urls.begin();
-    for( ; it_url != article_urls.end(); ++it_url ){
+    for( const std::string& url : article_urls ) {
 #ifdef _DEBUG
-        std::cout << "insert " << *it_url << std::endl;
+        std::cout << "insert " << url << std::endl;
 #endif
-        taburls.insert( *it_url );
+        taburls.insert( url );
     }
 
-    it_url = board_urls.begin();
-    for( ; it_url != board_urls.end(); ++it_url ){
+    for( const std::string& url : board_urls ) {
 #ifdef _DEBUG
-        std::cout << "insert " << *it_url << std::endl;
+        std::cout << "insert " << url << std::endl;
 #endif
-        taburls.insert( *it_url );
+        taburls.insert( url );
     }
 
     // root 
@@ -427,25 +425,6 @@ void History_Manager::delete_viewhistory( const std::string& url )
 }
 
 
-//
-// 現在表示中のViewのURL( url_old) を新しいURL( url_new )に変更
-//
-bool History_Manager::replace_current_url_viewhistory( const std::string& url_old, const std::string& url_new )
-{
-#ifdef _DEBUG
-    std::cout << "History_Manager::replace_current_url_viewhistory\n"
-              << "old = " << url_old << std::endl
-              << "new = " << url_new << std::endl;
-#endif
-
-    ViewHistory* history = get_viewhistory( url_old );
-    if( !history ) return false;
-
-    history->replace_current_url( url_new );
-    return true;
-}
-
-
 //
 // 履歴全体で url_old を url_new に変更
 //
