@@ -210,7 +210,7 @@ bool HistorySubMenu::slot_button_press( GdkEventButton* event, int i )
     // ポップアップメニュー表示
     if( event->button == 3 )
     {
-        m_popupmenu.popup( 0, gtk_get_current_event_time() );
+        m_popupmenu.popup_at_pointer( reinterpret_cast<GdkEvent*>( event ) );
     }
 
     return true;
@@ -314,7 +314,7 @@ void HistorySubMenu::slot_show_property()
         std::cout << "url " << info_list[ i ].url << std::endl;
 #endif
 
-        SKELETON::PrefDiag* pref = nullptr;
+        std::unique_ptr<SKELETON::PrefDiag> pref;
         switch( info_list[ i ].type ){
 
             case TYPE_THREAD: 
@@ -338,7 +338,6 @@ void HistorySubMenu::slot_show_property()
 
         if( pref ){
             pref->run();
-            delete pref;
         }
     }
 }
