@@ -8,26 +8,33 @@
 
 #include "viewhistoryitem.h"
 
+#include <memory>
 #include <string>
 #include <vector>
 
+
 namespace HISTORY
 {
     class ViewHistory
     {
         friend class History_Manager; // History_Manager 以外からは直接操作禁止
 
-        std::vector< ViewHistoryItem* > m_items;
+        std::vector<std::unique_ptr<ViewHistoryItem>> m_items;
 
-        int m_history_top;
-        int m_history_current;
-        int m_history_end;
+        int m_history_top{};
+        int m_history_current{};
+        int m_history_end{};
 
-        ViewHistory();
-        virtual ~ViewHistory();
+      public:
+
+        // privateだと std::list<ViewHistory> で要素の構築・削除ができない
+        ViewHistory() = default;
+        virtual ~ViewHistory() noexcept = default;
+
+      private:
 
         int get_size() const noexcept { return m_items.size(); }
-        const ViewHistoryItem* get_item( const int pos ) const { return m_items[ pos ]; }
+        const ViewHistoryItem* get_item( const int pos ) const { return m_items[ pos ].get(); }
 
         int get_top() const noexcept { return m_history_top; }
         int get_cur() const noexcept { return m_history_current; }
