@@ -10,32 +10,15 @@
 #include "misctime.h"
 #include "miscmsg.h"
 
-#include <sstream>
-#include <cstdio>
-#include <cstring>
+#include <chrono>
 #include <ctime>
 #include <iomanip>
+#include <locale>
+#include <sstream>
 #include <sys/time.h>
 #include <vector>
 
 
-//
-// gettimeofday()の秒を文字列で取得
-//
-std::string MISC::get_sec_str()
-{
-	std::ostringstream sec_str;
-
-	struct timeval tv;
-    struct timezone tz;
-    gettimeofday( &tv, &tz );
-
-    sec_str << tv.tv_sec;
-
-    return sec_str.str();
-}
-
-
 //
 // timeval を str に変換
 //
@@ -49,38 +32,24 @@ std::string MISC::timevaltostr( const struct timeval& tv )
 
 //
 // 時刻を紀元からの経過秒に直す
+// 日時のフォーマットはHTTPリクエストの形式(RFC 7232 IMF-fixdate)
 //
 time_t MISC::datetotime( const std::string& date )
 {
     if( date.empty() ) return 0;
 
-    struct tm tm_out;
-    memset( &tm_out, 0, sizeof( struct tm ) );
+    std::tm buf{};
+    std::istringstream iss( date );
+    iss.imbue( std::locale::classic() ); // Cロケール
 
-    // (注意) LC_TIMEが"C"でないと環境によってはstrptime()が失敗する
-    std::string lcl;
-    char *lcl_tmp = setlocale( LC_TIME, nullptr );
-    if( lcl_tmp ) lcl = lcl_tmp;
+    iss >> std::get_time( &buf, "%a, %d %b %Y %T GMT" );
+    if( iss.fail() ) return 0;
+
+    const std::time_t utc = timegm( &buf );
 #ifdef _DEBUG
-    std::cout << "locale = " << lcl << std::endl;
-#endif    
-    if( ! lcl.empty() ) setlocale( LC_TIME, "C" ); 
-    char *ret = strptime( date.c_str(), "%a, %d %b %Y %T %Z", &tm_out );
-    if( ! lcl.empty() ) setlocale( LC_TIME, lcl.c_str() ); 
-
-    if( ret == nullptr ) return 0;
-
-#ifdef USE_MKTIME
-    time_t t_ret = mktime( &tm_out );
-#else
-    time_t t_ret = timegm( &tm_out );
+    std::cout << "MISC::datetotime " << date << " -> " << utc << std::endl;
 #endif
-
-#ifdef _DEBUG
-    std::cout << "MISC::datetotime " << date << " -> " << t_ret << std::endl;
-#endif
-
-    return t_ret;
+    return utc;
 }
 
 
@@ -169,27 +138,23 @@ time_t timegm (struct tm *tm)
 
 // 実行時間測定用
 
-std::vector< struct timeval > tv_measurement;
+static std::vector<std::chrono::steady_clock::time_point> tv_measurement;
 
-void MISC::start_measurement( const int id )
+void MISC::start_measurement( const unsigned int id )
 {
-    while( (int)tv_measurement.size() <= id ){
-        struct timeval tv;
-        tv_measurement.push_back( tv );
+    if( tv_measurement.size() <= id ) {
+        tv_measurement.resize( id + 1 );
     }
-
-    gettimeofday( &tv_measurement[ id ], nullptr );
+    tv_measurement[id] = std::chrono::steady_clock::now();
 }
 
-int MISC::measurement( const int id )
+long long MISC::measurement( const unsigned int id )
 {
-    if( id >= (int)tv_measurement.size() ) return 0;
+    if( id >= tv_measurement.size() ) return 0;
 
-    struct timeval tv;
-    gettimeofday( &tv, nullptr );
+    const auto current = std::chrono::steady_clock::now();
+    const auto duration = current - tv_measurement[id];
+    tv_measurement[id] = current;
 
-    int ret = ( tv.tv_sec * 1000000 + tv.tv_usec ) - ( tv_measurement[ id ].tv_sec * 1000000 + tv_measurement[ id ].tv_usec );
-    tv_measurement[ id ] = tv;
-
-    return ret;
+    return std::chrono::duration_cast<std::chrono::nanoseconds>( duration ).count();
 }
