@@ -12,6 +12,8 @@
 #include "dbtree/spchar_decoder.h"
 #include "dbtree/node.h"
 
+#include <glib.h>
+
 #include <sstream>
 #include <cstring>
 #include <cstdio>
@@ -98,8 +100,7 @@ std::list< std::string > MISC::get_elisp_lists( const std::string& str )
     }
 
 #ifdef _DEBUG
-    std::list < std::string >::iterator it;
-    for( it = lists.begin(); it != lists.end(); ++it ) std::cout << "[" << *it << "]" << std::endl;
+    for( const std::string& s : lists ) std::cout << "[" << s << "]" << std::endl;
 #endif
     
     return lists;
@@ -199,10 +200,9 @@ std::list< std::string > MISC::StringTokenizer( const std::string& str, const ch
 std::list< std::string > MISC::remove_nullline_from_list( const std::list< std::string >& list_in )
 {
     std::list< std::string > list_ret;
-    std::list< std::string >::const_iterator it;    
-    for( it = list_in.begin(); it != list_in.end(); ++it ){
-        std::string tmp_str = MISC::remove_space( (*it) );
-        if( ! tmp_str.empty() ) list_ret.push_back( *it );
+    for( const std::string& s : list_in ) {
+        std::string tmp_str = MISC::remove_space( s );
+        if( ! tmp_str.empty() ) list_ret.push_back( s );
     }
 
     return list_ret;
@@ -215,10 +215,9 @@ std::list< std::string > MISC::remove_nullline_from_list( const std::list< std::
 std::list< std::string > MISC::remove_space_from_list( const std::list< std::string >& list_in )
 {
     std::list< std::string > list_ret;
-    std::list< std::string >::const_iterator it;    
-    for( it = list_in.begin(); it != list_in.end(); ++it ){
-        std::string tmp_str = MISC::remove_space( (*it) );
-        list_ret.push_back( tmp_str );
+    for( const std::string& s : list_in ) {
+        std::string tmp_str = MISC::remove_space( s );
+        list_ret.push_back( std::move( tmp_str ) );
     }
 
     return list_ret;
@@ -233,10 +232,9 @@ std::list< std::string > MISC::remove_commentline_from_list( const std::list< st
     const char commentchr = '#';
 
     std::list< std::string > list_ret;
-    std::list< std::string >::const_iterator it;    
-    for( it = list_in.begin(); it != list_in.end(); ++it ){
-        std::string tmp_str = MISC::remove_space( (*it) );
-        if( tmp_str.c_str()[ 0 ] != commentchr ) list_ret.push_back( *it );
+    for( const std::string& s : list_in ) {
+        std::string tmp_str = MISC::remove_space( s );
+        if( tmp_str[0] != commentchr ) list_ret.push_back( s );
     }
 
     return list_ret;
@@ -253,13 +251,11 @@ std::list< std::string > MISC::remove_commentline_from_list( const std::list< st
 //
 std::list< std::string > MISC::strtolist( const std::string& str_in )
 {
-    std::list< std::string > list_tmp;
     std::list< std::string > list_ret;
 
-    list_tmp = MISC::split_line( str_in );
-    std::list< std::string >::iterator it = list_tmp.begin();
-    for( ; it != list_tmp.end(); ++it ){
-        if( !( *it ).empty() ) list_ret.push_back( MISC::recover_quot( ( *it ) ) );
+    std::list<std::string> list_tmp = MISC::split_line( str_in );
+    for( const std::string& s : list_tmp ) {
+        if( ! s.empty() ) list_ret.push_back( MISC::recover_quot( s ) );
     }
 
     return list_ret;
@@ -277,9 +273,8 @@ std::list< std::string > MISC::strtolist( const std::string& str_in )
 std::string MISC::listtostr( const std::list< std::string >& list_in )
 {
     std::string str_out;
-    std::list< std::string >::const_iterator it = list_in.begin();
-    for( ; it != list_in.end(); ++it ){
-        if( ! ( *it ).empty() ) str_out += " \"" + MISC::replace_quot( ( *it ) )  + "\"";
+    for( const std::string& s : list_in ) {
+        if( ! s.empty() ) str_out.append( " \"" + MISC::replace_quot( s )  + "\"" );
     }
 
     return str_out;
@@ -287,6 +282,25 @@ std::string MISC::listtostr( const std::list< std::string >& list_in )
 
 
 
+//
+// list_in から空文字列を除き suffix でつなげて返す
+// 他のプログラミング言語にあるjoin()と動作が異なり返り値の末尾にもsuffixが付く
+//
+// (例) {"aa", "", "bb", "cc"}, '!' -> "aa!bb!cc!"
+//
+std::string MISC::concat_with_suffix( const std::list<std::string>& list_in, char suffix )
+{
+    std::string str_out;
+    for( const std::string& s : list_in ) {
+        if( s.empty() ) continue;
+        str_out.append( s );
+        str_out.push_back( suffix );
+    }
+    return str_out;
+}
+
+
+
 //
 // strの前後の空白削除
 //
@@ -454,8 +468,8 @@ std::list< std::string > MISC::replace_str_list( const std::list< std::string >&
                                                  const std::string& str1, const std::string& str2 )
 {
     std::list< std::string > list_out;
-    std::list< std::string >::const_iterator it = list_in.begin();
-    for( ; it != list_in.end(); ++it ) list_out.push_back( replace_str( *it, str1, str2 ) );
+    std::transform( list_in.cbegin(), list_in.cend(), std::back_inserter( list_out ),
+                    [&]( const std::string& s ) { return replace_str( s, str1, str2 ); } );
     return list_out;
 }
 
@@ -556,11 +570,11 @@ int MISC::str_to_uint( const char* str, size_t& dig, size_t& n )
 
         else{
 
-            const unsigned char in2 = (* ( str +1 ));
-            const unsigned char in3 = (* ( str +2 ));
+            const auto in2 = static_cast<unsigned char>( in == 0xEF ? *( str + 1 ) : 0 );
+            const auto in3 = static_cast<unsigned char>( in2 == 0xBC ? *( str + 2 ) : 0 );
 
             // utf-8
-            if( in == 0xef && in2 == 0xbc && ( 0x90 <= in3 && in3 <= 0x99 ) ){
+            if( 0x90 <= in3 && in3 <= 0x99 ){
                 out = out*10 + ( in3 - 0x90 );
                 ++dig;
                 str += 3;
@@ -580,20 +594,23 @@ int MISC::str_to_uint( const char* str, size_t& dig, size_t& n )
 //
 std::string MISC::intlisttostr( const std::list< int >& list_num )
 {
+    assert( ! list_num.empty() );
+
     std::ostringstream comment;
 
     std::list < int >::const_iterator it = list_num.begin();
 
     bool comma = false;
     int num_from = *it;
-    int num_to = -1;
-    int i = 0;
+    int num_to = -1; // -1 は番兵
+    int i = 0; // 連番判定に使う
     for(;;){
 
         ++i;
         ++it;
-        const int num = *it;
-        if( num_from + i != num || it == list_num.end() ){
+        const bool loop_end{ it == list_num.end() };
+        const int num{ loop_end ? -1 : *it };
+        if( num_from + i != num || loop_end ) {
 
             if( comma ) comment << ",";
             comment << num_from;
@@ -603,8 +620,9 @@ std::string MISC::intlisttostr( const std::list< int >& list_num )
             i = 0;
             comma = true;
 
-            if( it == list_num.end() ) break;
+            if( loop_end ) break;
         }
+        // 数字が連番のときは記録しておく
         else num_to = num;
     }
 
@@ -1177,7 +1195,7 @@ std::string MISC::url_encode( const char* str, const size_t n )
             ( c != '@' ) &&
             ( c != '_' )){
 
-            snprintf( str_tmp, tmplng , "%%%02x", c );
+            std::snprintf( str_tmp, tmplng, "%%%02X", c );
         }
         else {
             str_tmp[ 0 ] = c;
@@ -1219,12 +1237,10 @@ std::string MISC::charset_url_encode( const std::string& str, const std::string&
 std::string MISC::charset_url_encode_split( const std::string& str, const std::string& charset )
 {
     std::list< std::string > list_str = MISC::split_line( str );
-    std::list< std::string >::iterator it = list_str.begin();
     std::string str_out;
-    for( ; it != list_str.end(); ++it ){
-
-        if( it != list_str.begin() ) str_out += "+";
-        str_out += MISC::charset_url_encode( *it, charset );
+    for( const std::string& s : list_str ) {
+        if( ! str_out.empty() ) str_out.push_back( '+' );
+        str_out.append( MISC::charset_url_encode( s, charset ) );
     }
 
     return str_out;
@@ -1236,7 +1252,7 @@ std::string MISC::charset_url_encode_split( const std::string& str, const std::s
 //
 std::string MISC::base64( const std::string& str )
 {
-    char table[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+    constexpr const char table[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
     int lng = str.length();
 
@@ -1673,9 +1689,8 @@ std::string MISC::utf8_fix_wavedash( const std::string& str, const int mode )
 std::string MISC::toupper_str( const std::string& str )
 {
     std::string str_out;
-    const size_t str_length = str.length();
-
-    for( size_t i = 0; i < str_length ; ++i ) str_out += toupper( str[ i ] );
+    std::transform( str.cbegin(), str.cend(), std::back_inserter( str_out ),
+                    []( unsigned char c ) { return std::toupper( c ); } );
 
     return str_out;
 }
@@ -1687,8 +1702,8 @@ std::string MISC::toupper_str( const std::string& str )
 std::list< std::string > MISC::toupper_list( const std::list< std::string >& list_str )
 {
     std::list< std::string > list_out;
-    std::list< std::string >::const_iterator it = list_str.begin();
-    for( ; it != list_str.end() ; ++it ) list_out.push_back( MISC::toupper_str( *it ) );
+    std::transform( list_str.cbegin(), list_str.cend(), std::back_inserter( list_out ),
+                    []( const std::string& s ) { return MISC::toupper_str( s ); } );
 
     return list_out;
 }
@@ -1701,9 +1716,8 @@ std::list< std::string > MISC::toupper_list( const std::list< std::string >& lis
 std::string MISC::tolower_str( const std::string& str )
 {
     std::string str_out;
-    const size_t str_length = str.length();
-
-    for( size_t i = 0; i < str_length; ++i ) str_out += tolower( str[ i ] );
+    std::transform( str.cbegin(), str.cend(), std::back_inserter( str_out ),
+                    []( unsigned char c ) { return std::tolower( c ); } );
 
     return str_out;
 }
@@ -1806,8 +1820,8 @@ bool MISC::has_widechar( const char* str )
 
             if( in == 0xef ){
 
-                const unsigned char in2 = * ( str + 1 );
-                const unsigned char in3 = * ( str + 2 );
+                const auto in2 = static_cast<unsigned char>( *( str + 1 ) );
+                const auto in3 = static_cast<unsigned char>( in2 != '\0' ? *( str + 2 ) : 0 );
 
                 if( in2 == 0xbc ){
 
@@ -2037,3 +2051,23 @@ std::string MISC::parse_html_form_action( const std::string& html )
     }
     return path;
 }
+
+
+// haystack の pos 以降から最初に needle と一致する位置を返す (ASCIIだけignore case)
+// 見つからない場合は std::string::npos を返す、needle が空文字列なら pos を返す
+std::size_t MISC::ascii_ignore_case_find( const std::string& haystack, const std::string& needle, std::size_t pos )
+{
+    if( haystack.size() < pos ) return std::string::npos;
+    if( needle.empty() ) return pos;
+
+    const char head[3] = { g_ascii_toupper( needle[0] ), g_ascii_tolower( needle[0] ) };
+    std::size_t i = pos;
+    while( true ) {
+        i = haystack.find_first_of( head, i );
+        if( i == std::string::npos ) break;
+        // ヌル終端文字列が要件なので注意
+        if( g_ascii_strncasecmp( haystack.c_str() + i, needle.c_str(), needle.size() ) == 0 ) break;
+        ++i;
+    }
+    return i;
+}
