@@ -37,9 +37,9 @@
 #include "global.h"
 #include "compmanager.h"
 
-#include <sstream>
-#include <sys/time.h>
 #include <cstring>
+#include <ctime>
+#include <sstream>
 
 
 using namespace MESSAGE;
@@ -62,18 +62,10 @@ enum
 
 
 MessageViewBase::MessageViewBase( const std::string& url )
-    : SKELETON::View( url ),
-      m_post( nullptr ),
-      m_preview( nullptr ),
-      m_entry_name( CORE::COMP_NAME ),
-      m_entry_mail( CORE::COMP_MAIL ),
-      m_text_message( nullptr ),
-      m_enable_focus( true ),
-      m_lng_str_enc( 0 ),
-      m_counter( 0 ),
-      m_text_changed( false ),
-      m_over_lines( false ),
-      m_over_lng( false )
+    : SKELETON::View( url )
+    , m_entry_name( CORE::COMP_NAME )
+    , m_entry_mail( CORE::COMP_MAIL )
+    , m_enable_focus( true )
 {
 #ifdef _DEBUG
     std::cout << "MessageViewBase::MessageViewBase " << get_url() << std::endl;
@@ -85,7 +77,7 @@ MessageViewBase::MessageViewBase( const std::string& url )
     m_max_line = DBTREE::line_number( get_url() ) * 2;
     m_max_str = DBTREE::message_count( get_url() );
 
-    m_iconv = new JDLIB::Iconv( DBTREE::board_charset( get_url() ), "UTF-8" );;
+    m_iconv = std::make_unique<JDLIB::Iconv>( DBTREE::board_charset( get_url() ), "UTF-8" );;
 
     m_lng_iconv = m_max_str * 3;
     if( ! m_lng_iconv ) m_lng_iconv = MAX_STR_ICONV;
@@ -109,17 +101,10 @@ MessageViewBase::~MessageViewBase()
     CORE::get_completion_manager()->set_query( CORE::COMP_NAME, name );
     CORE::get_completion_manager()->set_query( CORE::COMP_MAIL, mail );
 
-    if( m_preview ) delete m_preview;
-    m_preview = nullptr;
-
     if( m_post ){
         m_post->terminate_load();
-        delete m_post;
+        m_post.reset();
     }
-    m_post = nullptr;
-
-    if( m_iconv ) delete m_iconv;
-    m_iconv = nullptr;
 
     SESSION::set_close_mes( ! is_locked() );
 }
@@ -238,19 +223,14 @@ void MessageViewBase::init_color()
             const auto bg = Gdk::RGBA( CONFIG::get_color( COLOR_BACK_MESSAGE ) ).to_string();
             const auto sel_fg = Gdk::RGBA( CONFIG::get_color( COLOR_CHAR_MESSAGE_SELECTION ) ).to_string();
             const auto sel_bg = Gdk::RGBA( CONFIG::get_color( COLOR_BACK_MESSAGE_SELECTION ) ).to_string();
-#if GTKMM_CHECK_VERSION(3,20,0)
-            constexpr const char* const caret_prop = u8"caret-color";
-#else
-            constexpr const char* const caret_prop = u8"-GtkWidget-cursor-color";
-#endif
             m_text_message->update_style( Glib::ustring::compose(
                 u8R"(
-                    .%1, .%1 text { color: %2; background-color: %3; %4: %2; }
+                    .%1, .%1 text { color: %2; background-color: %3; caret-color: %2; }
                     .%1:selected, .%1:selected:focus,
                     .%1 text:selected, .%1 text:selected:focus,
-                    .%1 text selection, .%1 text selection:focus { color: %5; background-color: %6; }
+                    .%1 text selection, .%1 text selection:focus { color: %4; background-color: %5; }
                 )",
-                classname, fg, bg, caret_prop, sel_fg, sel_bg ) );
+                classname, fg, bg, sel_fg, sel_bg ) );
         }
     }
 }
@@ -262,7 +242,7 @@ void MessageViewBase::set_message( const std::string& msg )
 }
 
 
-Glib::ustring MessageViewBase::get_message()
+Glib::ustring MessageViewBase::get_message() const
 {
     if( m_text_message ) return m_text_message->get_text();
 
@@ -484,7 +464,7 @@ void MessageViewBase::pack_widget()
     m_text_message->get_buffer()->signal_changed().connect( sigc::mem_fun(*this, &MessageViewBase::slot_text_changed ) );
 
     // プレビュー
-    m_preview = CORE::ViewFactory( CORE::VIEW_ARTICLEPREVIEW, get_url() );
+    m_preview.reset( CORE::ViewFactory( CORE::VIEW_ARTICLEPREVIEW, get_url() ) );
 
     m_notebook.set_show_tabs( false );
     m_notebook.set_show_border( false );
@@ -615,38 +595,41 @@ void MessageViewBase::write()
     // fusianasan チェック
     if( DBTREE::default_noname( get_url() ) == "fusianasan" ) DBTREE::board_set_check_noname( get_url(), true );
 
+    const char* reason = nullptr;
+
     // 名無し書き込みチェック
     if( DBTREE::board_check_noname( get_url() ) ){
 
         std::string name = get_entry_name().get_text();
         if( name.empty() ){
-            SKELETON::MsgDiag mdiag( get_parent_win(), "名前欄が空白です。fusianasan 書き込みになる可能性があります。" );
-            mdiag.run();
-            return;
+            reason = "名前欄が空欄です。fusianasan 書き込みになる可能性があります。";
         }
     }
 
-
     // 行数チェック
-    if( m_max_line ){
+    if( ! reason && m_max_line ){
 
         if( m_text_message && m_text_message->get_buffer()->get_line_count() > m_max_line ){
-            SKELETON::MsgDiag mdiag( get_parent_win(), "行数が多すぎます。" );
-            mdiag.run();
-            return;
+            reason = "行数が多すぎます。";
         }
     }
 
     // バイト数チェック
-    if( m_max_str ){
+    if( ! reason && m_max_str ){
 
         if( m_lng_str_enc > m_max_str ){
-            SKELETON::MsgDiag mdiag( get_parent_win(), "文字数が多すぎます。" );
-            mdiag.run();
-            return;
+            reason = "文字数が多すぎます。";
         }
     }
 
+    if( reason ) {
+        SKELETON::MsgDiag mdiag( get_parent_win(), "投稿がキャンセルされました。" );
+        mdiag.property_message_type() = Gtk::MESSAGE_WARNING;
+        mdiag.set_secondary_text( reason );
+        mdiag.run();
+        return;
+    }
+
     const std::string msg = create_message();
     if( msg.empty() ) return;
 
@@ -810,9 +793,8 @@ void MessageViewBase::post_msg( const std::string& msg, bool new_article )
 
     if( m_post ){
         m_post->terminate_load();
-        delete m_post;
     }
-    m_post = new Post( this, get_url(),  msg, new_article );
+    m_post = std::make_unique<Post>( this, get_url(),  msg, new_article );
     m_post->sig_fin().connect( sigc::mem_fun( *this, &MessageViewBase::post_fin ) );
     m_post->post_msg();
 
@@ -908,7 +890,7 @@ void MessageViewBase::slot_switch_page( Gtk::Widget*, guint page )
 
             const std::string name_field = m_entry_name.get_text();
 
-            const size_t trip_pos = name_field.find( "#", 0 );
+            const size_t trip_pos = name_field.find( '#', 0 );
 
             const std::string name = MISC::html_escape( name_field.substr( 0, trip_pos ) );
 
@@ -927,10 +909,8 @@ void MessageViewBase::slot_switch_page( Gtk::Widget*, guint page )
 
         ss << "<>" << mail  << "<>";
 
-        struct timeval tv;
-        struct timezone tz;
-        gettimeofday( &tv, &tz );
-        ss << MISC::timettostr( tv.tv_sec, MISC::TIME_WEEK );
+        const std::time_t current = std::time( nullptr );
+        ss << MISC::timettostr( current, MISC::TIME_WEEK );
 
         ss << " ID:???" << "<>" << msg << "<>\n";
 
