@@ -375,14 +375,13 @@ void Post::receive_finish()
     std::cout << "MSG: [" << msg << "]\n";
     std::cout << "ERR: [" << m_errmsg << "]\n";
 
-    std::list< std::string >::const_iterator it = list_cookies.begin();
-    for( ; it != list_cookies.end(); ++it ) std::cout << "cookie : [" << (*it) << "]\n";
+    for( const std::string& cookie : list_cookies ) std::cout << "cookie : [" << cookie << "]\n";
 
     std::cout << "location: [" << location() << "]\n";
 #endif
 
     // クッキーのセット
-    const bool empty_cookies = DBTREE::board_cookie_for_request( m_url ).empty();
+    const bool empty_cookies = DBTREE::board_cookie_for_post( m_url ).empty();
     if( list_cookies.size() ) DBTREE::board_set_list_cookies( m_url, list_cookies );
 
     // 成功
