@@ -26,7 +26,7 @@ namespace SKELETON
 
         std::map< Gtk::MenuItem*, int > m_map_items;
 
-        Gtk::MenuItem* m_activeitem;
+        Gtk::MenuItem* m_activeitem{};
 
       public:
 
@@ -44,7 +44,7 @@ namespace SKELETON
 
       private:
 
-        int get_size();
+        int get_size() const;
 
         void set_text( const std::string& text );
         void create_menuitem( Glib::RefPtr< Gtk::ActionGroup > actiongroup, Gtk::Menu* menu, const int id );
