@@ -45,7 +45,6 @@ DragTreeView::DragTreeView( const std::string& url, const std::string& dndtarget
 #endif
 
     set_enable_search( false );
-    set_rules_hint( CONFIG::get_use_tree_gtkrc() );
     add_events( Gdk::LEAVE_NOTIFY_MASK );
 
     auto context = get_style_context();
@@ -80,10 +79,8 @@ DragTreeView::DragTreeView( const std::string& url, const std::string& dndtarget
 }
 
 
-DragTreeView::~DragTreeView()
-{
-    delete_popup();
-}
+// メンバーに不完全型のスマートポインターがあるためデストラクタはinlineにできない
+DragTreeView::~DragTreeView() noexcept = default;
 
 
 //
@@ -198,7 +195,7 @@ void DragTreeView::show_popup( const std::string& url, View* view )
 
     delete_popup();
 
-    m_popup_win = new PopupWin( this, view, mrg_x, mrg_y );
+    m_popup_win = std::make_unique<PopupWin>( this, view, mrg_x, mrg_y );
     m_popup_win->signal_leave_notify_event().connect( sigc::mem_fun( *this, &DragTreeView::slot_popup_leave_notify_event ) );
     m_popup_win->sig_hide_popup().connect( sigc::mem_fun( *this, &DragTreeView::hide_popup ) );
 
@@ -264,10 +261,8 @@ void DragTreeView::delete_popup()
         std::cout << "DragTreeView::delete_popup\n";
 #endif
 
-        delete m_popup_win;
-        m_popup_win = nullptr;
-
-        m_pre_popup_url = std::string();
+        m_popup_win.reset();
+        m_pre_popup_url.clear();
         m_popup_shown = false;
     }
 }
@@ -561,7 +556,7 @@ void DragTreeView::slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel
     int rownum = atoi( path_str.c_str() );
     if( rownum %2 ) even = true;
 
-    size_t pos = path_str.find( ":" );
+    size_t pos = path_str.find( ':' );
     while( pos != std::string::npos ){
         path_str = path_str.substr( pos+1 );
         rownum = atoi( path_str.c_str() );
@@ -569,7 +564,7 @@ void DragTreeView::slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel
         if( ( even && ( rownum %2 ) ) || ( ! even && !( rownum %2 ) ) ) even = true;
         else even = false;
 
-        pos = path_str.find( ":" );
+        pos = path_str.find( ':' );
     }
 
     // 偶数行に色を塗る
