@@ -42,12 +42,11 @@ static inline bool is_separate_char( char32_t c )
 }
 
 
-EditTextView::EditTextView() :
-    Gtk::TextView(),
-    m_cancel_change( false ),
-    m_line_offset( -1 ),
-    m_context_menu( nullptr ),
-    m_aapopupmenu( nullptr )
+EditTextView::EditTextView()
+    : Gtk::TextView()
+    , m_pre_offset{ -1 }
+    , m_pre_line{ -1 }
+    , m_line_offset{ -1 }
 {
     // コントロールモード設定
     m_control.add_mode( CONTROL::MODE_EDIT );
@@ -61,11 +60,8 @@ EditTextView::EditTextView() :
 }
 
 
-EditTextView::~EditTextView()
-{
-    if( m_aapopupmenu ) delete m_aapopupmenu;
-    m_aapopupmenu = nullptr;
-}
+// メンバーに不完全型のスマートポインターがあるためデストラクタはinlineにできない
+EditTextView::~EditTextView() noexcept = default;
 
 
 //
@@ -483,8 +479,8 @@ void EditTextView::on_populate_popup( Gtk::Menu* menu )
     menuitem->signal_activate().connect( sigc::mem_fun( *this, &EditTextView::slot_write_jdinfo ) );
     menu->prepend( *menuitem );
 
-    // 変換(スペース⇔&nbsp;)
-    menuitem = Gtk::manage( new Gtk::MenuItem( "変換(スペース⇔&nbsp;)" ) );
+    // 変換(スペース⇔&#160;)
+    menuitem = Gtk::manage( new Gtk::MenuItem( "変換(スペース⇔&#160;)" ) );
     menuitem->signal_activate().connect( sigc::mem_fun( *this, &EditTextView::slot_convert_space ) );
     menu->prepend( *menuitem );
 
@@ -540,7 +536,7 @@ void EditTextView::slot_quote_clipboard()
 
 
 //
-// 変換(スペース⇔&nbsp;)
+// 変換(スペース⇔&#160;)
 //
 void EditTextView::slot_convert_space()
 {
@@ -550,10 +546,10 @@ void EditTextView::slot_convert_space()
     std::string text = buffer->get_text();
     std::string converted;
 
-    // &nbsp;が含まれていたらスペースに変換する
-    if( text.find( "&nbsp;", 0 ) != std::string::npos )
+    // &#160;が含まれていたらスペースに変換する
+    if( text.find( "&#160;" ) != std::string::npos )
     {
-        converted = MISC::replace_str( text, "&nbsp;", " " );
+        converted = MISC::replace_str( text, "&#160;", " " );
     }
     else
     {
@@ -565,13 +561,13 @@ void EditTextView::slot_convert_space()
                 // 行末のスペースを取り除く
                 line.erase( line.find_last_not_of( ' ' ) + 1 );
 
-                // 行頭のスペースを&nbsp;に変換する
-                if( ! line.empty() && line.front() == ' ' ) {
-                    line.replace( 0, 1, "&nbsp;" );
+                // 行頭のスペースを&#160;に変換する
+                if( line.front() == ' ' ) {
+                    line.replace( 0, 1, "&#160;" );
                 }
 
-                // 連続スペースを&nbsp;に変換する
-                converted.append( MISC::replace_str( line, "  ", " &nbsp;" ) );
+                // 連続スペースを&#160;に変換する
+                converted.append( MISC::replace_str( line, "  ", " &#160;" ) );
             }
 
             converted.push_back( '\n' );
@@ -652,9 +648,7 @@ void EditTextView::show_aalist_popup()
 {
     if( CORE::get_aamanager()->get_size() )
     {
-        if( m_aapopupmenu ) delete m_aapopupmenu;
-
-        m_aapopupmenu = Gtk::manage( new AAMenu( *dynamic_cast< Gtk::Window* >( get_toplevel() ) ) );
+        m_aapopupmenu = std::make_unique<AAMenu>( *dynamic_cast<Gtk::Window*>( get_toplevel() ) );
 
         m_aapopupmenu->sig_selected().connect( sigc::mem_fun( *this, &EditTextView::slot_aamenu_selected ) );
         m_aapopupmenu->signal_map().connect( sigc::mem_fun( *this, &EditTextView::slot_map_aamenu ) ); 
