@@ -20,33 +20,14 @@ enum
 };
 
 
-MenuButton::MenuButton( const bool show_arrow, Gtk::Widget& label )
-    : m_label( nullptr )
+MenuButton::MenuButton( const bool show_arrow, Gtk::Widget* label, Gtk::PackOptions options )
+    : m_label{ label }
+    , m_enable_sig_clicked{ true }
 {
-    setup( show_arrow, &label );
-}
+    Gtk::Box* hbox = Gtk::manage( new Gtk::Box( Gtk::ORIENTATION_HORIZONTAL ) );
 
-
-MenuButton::MenuButton( const bool show_arrow, const int id )
-    : m_label( nullptr )
-{
-    setup( show_arrow, Gtk::manage( new Gtk::Image( ICON::get_icon( id ) ) ), Gtk::PACK_SHRINK );
-}
-
-
-void MenuButton::setup( const bool show_arrow, Gtk::Widget* label, Gtk::PackOptions options, guint padding )
-{
-    const int space = 4;
-
-    m_label = label;
-    m_popupmenu =  nullptr;
-    m_on_arrow = false;
-    m_enable_sig_clicked = true;
-
-    Gtk::HBox *hbox = Gtk::manage( new Gtk::HBox() );
-
-    hbox->set_spacing( space );
-    if( m_label ) hbox->pack_start( *m_label, options, padding );
+    hbox->set_spacing( 4 );
+    if( m_label ) hbox->pack_start( *m_label, options );
 
     if( show_arrow ){
         m_arrow = Gtk::manage( new Gtk::Image() );
@@ -73,7 +54,7 @@ void MenuButton::setup( const bool show_arrow, Gtk::Widget* label, Gtk::PackOpti
         Glib::RefPtr< Gtk::Action > action = Gtk::Action::create( "menu" + std::to_string( i ), "dummy" );
         action->set_accel_group( agroup );
         Gtk::MenuItem* item = Gtk::manage( action->create_menu_item() );
-        actiongroup->add( action, sigc::bind< int >( sigc::mem_fun( *this, &MenuButton::slot_menu_selected ), i ) );
+        actiongroup->add( action, [this, i] { slot_menu_selected( i ); } );
         m_menuitems.push_back( item );
     }
 
@@ -81,10 +62,15 @@ void MenuButton::setup( const bool show_arrow, Gtk::Widget* label, Gtk::PackOpti
 }
 
 
-// virtual
-MenuButton::~MenuButton()
+MenuButton::MenuButton( const bool show_arrow, Gtk::Widget& label )
+    : MenuButton( show_arrow, &label )
+{
+}
+
+
+MenuButton::MenuButton( const bool show_arrow, const int id )
+    : MenuButton( show_arrow, Gtk::manage( new Gtk::Image( ICON::get_icon( id ) ) ), Gtk::PACK_SHRINK )
 {
-    if( m_popupmenu ) delete m_popupmenu;
 }
 
 
@@ -105,14 +91,13 @@ void MenuButton::append_menu( std::vector< std::string >& items )
     if( m_popupmenu ){
         const int menusize = m_popupmenu->get_children().size();
         for( int i = 0; i < menusize; ++i ) m_popupmenu->remove( *m_menuitems[ i ] );
-        delete m_popupmenu;
+        m_popupmenu.reset();
     }
-    m_popupmenu = nullptr;
 
     if( ! items.size() ) return;
 
     // 新しくメニューを作成して項目追加
-    m_popupmenu = Gtk::manage( new Gtk::Menu() );
+    m_popupmenu = std::make_unique<Gtk::Menu>();
     const size_t size = MIN( items.size(), MAX_MENU_SIZE );
     for( size_t i = 0 ; i < size; ++i ){
 
@@ -142,8 +127,8 @@ void MenuButton::show_popupmenu()
 {
     if( ! m_popupmenu ) return;
 
-    m_popupmenu->popup( Gtk::Menu::SlotPositionCalc( sigc::mem_fun( *this, &MenuButton::slot_popup_pos ) ),
-                        0, gtk_get_current_event_time() );
+    // Specify the current event by nullptr.
+    m_popupmenu->popup_at_widget( this, Gdk::GRAVITY_SOUTH_WEST, Gdk::GRAVITY_NORTH_WEST, nullptr );
 }
 
 
@@ -174,20 +159,6 @@ void MenuButton::on_clicked()
 }
 
 
-//
-// ポップアップメニューの位置決め
-//
-void MenuButton::slot_popup_pos( int& x, int& y, bool& push_in )
-{
-    int ox, oy;
-    get_window()->get_origin( ox, oy );
-    Gdk::Rectangle rect = get_allocation();
-    x = ox + rect.get_x();
-    y = oy + rect.get_y() + rect.get_height();
-    push_in = false;
-}
-
-
 bool MenuButton::slot_enter( GdkEventCrossing* event )
 {
 #ifdef _DEBUG
