@@ -94,14 +94,18 @@ JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
         context->add_class( s_css_stat_label );
         context->add_provider( m_stat_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION );
     }
-}
 
-
-JDWindow::~JDWindow()
-{
-    if( m_dummywin ) delete m_dummywin;
-    if( m_vbox_view ) delete m_vbox_view;
-    if( m_scrwin ) delete m_scrwin;
+    try {
+        m_stat_provider->load_from_data(
+            ".red:not(:selected), .red:active:not(:selected) { color: white; background-color: red; }"
+            ".green:not(:selected), .green:active:not(:selected) { color: white; background-color: green; }"
+            ".blue:not(:selected), .blue:active:not(:selected) { color: white; background-color: blue; }" );
+    }
+    catch( Gtk::CssProviderError& err ) {
+#ifdef _DEBUG
+        std::cout << "ERROR:JDWindow::JDWindow css fail " << err.what() << std::endl;
+#endif
+    }
 }
 
 
@@ -111,20 +115,14 @@ void JDWindow::init_win()
     // フォーカスアウトで折り畳む場合
     if( m_fold_when_focusout ){
 
-        m_scrwin = new Gtk::ScrolledWindow();
-        m_vbox_view = new SKELETON::JDVBox();
+        m_scrwin = std::make_unique<Gtk::ScrolledWindow>();
+        m_vbox_view = std::make_unique<SKELETON::JDVBox>();
 
         m_scrwin->set_size_request( 0, 0 );
-        m_scrwin->set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_NEVER );
+        m_scrwin->set_policy( Gtk::POLICY_EXTERNAL, Gtk::POLICY_EXTERNAL );
         m_scrwin->add( *m_vbox_view );
         m_vbox.pack_remove_end( false, *m_scrwin, Gtk::PACK_EXPAND_WIDGET );
 
-        m_dummywin = new Gtk::Window();
-        m_dummywin->resize( 1, 1 );
-        m_dummywin->move( -1, -1 );
-        m_dummywin->hide();
-        m_dummywin->set_skip_taskbar_hint( true );
-
         set_skip_taskbar_hint( true );
         resize( get_width_win(), 1 );
         move_win( get_x_win(), get_y_win() );
@@ -342,7 +340,7 @@ void JDWindow::set_win_pos()
 
 
 // hide 中
-bool JDWindow::is_hide()
+bool JDWindow::is_hide() const
 {
     return ( m_mode == JDWIN_HIDE );
 }
@@ -420,24 +418,18 @@ void JDWindow::set_status_color( const std::string& color )
     std::cout << "JDWindow::set_status_color " << color << std::endl;
 #endif
 
-    // TODO: 色を毎回指定するかわりにcssクラスの交換でスタイルを変更する
-    Glib::ustring css;
-    if( color.empty() ) {
-        // テキスト部分が上手く配色されないGTKテーマがあるので明示的に設定する
-        css = Glib::ustring::compose( u8".%1:not(:selected) { color: unset; }", s_css_stat_label );
-    }
-    else {
-        css = Glib::ustring::compose(
-            u8".%1:not(:selected), %1:active:not(:selected) { color: white; background-color: %2; }",
-            s_css_stat_label, Gdk::RGBA( color ).to_string() );
-    }
-    try {
-        m_stat_provider->load_from_data( css );
-    }
-    catch( Gtk::CssProviderError& err ) {
-#ifdef _DEBUG
-        std::cout << "ERROR:JDWindow::set_status_color fail " << err.what() << std::endl;
-#endif
+    auto context = m_label_stat.get_style_context();
+    context->remove_class( "red" );
+    context->remove_class( "green" );
+    context->remove_class( "blue" );
+    if( ! color.empty() ) context->add_class( color );
+
+    if( m_mginfo.get_realized() ) {
+        context = m_mginfo.get_style_context();
+        context->remove_class( "red" );
+        context->remove_class( "green" );
+        context->remove_class( "blue" );
+        if( ! color.empty() ) context->add_class( color );
     }
 }
 
@@ -456,9 +448,9 @@ void JDWindow::set_transient( bool set )
             m_transient = true;
         }
 
-        // ダミーwindowを使ってtransientを外す
+        // transientを外す
         else if( ! set && m_transient ){
-            set_transient_for( *m_dummywin );
+            unset_transient_for();
             m_transient = false;
         }
     }
