@@ -27,10 +27,9 @@ std::set< std::string > Dom::m_static_html_elements;
 
 // コンストラクタ
 Dom::Dom( const int type, const std::string& name, const bool html )
-    : m_html( html ),
-      m_nodeType( type ),
-      m_nodeName( name ),
-      m_parentNode( nullptr )
+    : m_html( html )
+    , m_nodeType( type )
+    , m_nodeName( name )
 {
     // HTMLの場合に空要素として扱う物の内で、使われていそうな物( 小文字で統一 )
     if( html && m_static_html_elements.empty() )
@@ -57,12 +56,11 @@ Dom::~Dom() noexcept
 
 // コピーコンストラクタ
 Dom::Dom( const Dom& dom )
-    : m_html( dom.m_html ),
-      m_nodeType( dom.m_nodeType ),
-      m_nodeName( dom.m_nodeName ),
-      m_nodeValue( dom.m_nodeValue ),
-      m_parentNode( nullptr ),
-      m_attributes( dom.m_attributes )
+    : m_html( dom.m_html )
+    , m_nodeType( dom.m_nodeType )
+    , m_nodeName( dom.m_nodeName )
+    , m_nodeValue( dom.m_nodeValue )
+    , m_attributes( dom.m_attributes )
 {
     copy_childNodes( dom );
 }
@@ -199,8 +197,8 @@ void Dom::parse( const std::string& str )
                     }
 
                     // 空要素でない同名の開始タグを見つけたらカウントを増やす
-                    if( close_tag.compare( 0, name.length(), name ) == 0
-                     && close_tag.compare( close_tag.length() - 1, 1, "/" ) != 0 ) ++count;
+                    if( close_tag.rfind( name, 0 ) == 0
+                        && close_tag.compare( close_tag.size() - 1, 1, "/" ) != 0 ) ++count;
                     // 終了タグを見つけたらカウントを減らす
                     else if( close_tag.compare( 0, name.length() + 1, "/" + name ) == 0 ) --count;
 
@@ -622,22 +620,14 @@ bool Dom::removeChild( Dom* node )
 
 
 //
-// ノード：insertBefore()
+// insertBefore() の機能をフルに使っていなかったためシンプルにした関数を導入する
 //
-Dom* Dom::insertBefore( const int node_type, const std::string& node_name, Dom* insNode )
+Dom* Dom::emplace_front( const int node_type, const std::string& node_name )
 {
-    if( ! insNode ) return appendChild( node_type, node_name );
-
-    Dom* newNode = nullptr;
-
-    const auto it = std::find( m_childNodes.begin(), m_childNodes.end(), insNode );
-    if( it != m_childNodes.end() )
-    {
-        newNode = new Dom( node_type, node_name );
-        newNode->m_parentNode = insNode->m_parentNode;
-        m_childNodes.insert( it, newNode );
-    }
-    return newNode;
+    Dom* node = new Dom( node_type, node_name );
+    node->m_parentNode = this;
+    m_childNodes.push_front( node );
+    return node;
 }
 
 
